# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorboard/uploader/proto/blob.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%tensorboard/uploader/proto/blob.proto\x12\x13tensorboard.service\"F\n\x04\x42lob\x12\x0f\n\x07\x62lob_id\x18\x01 \x01(\t\x12-\n\x05state\x18\x02 \x01(\x0e\x32\x1e.tensorboard.service.BlobState\"<\n\x11\x42lobSequenceEntry\x12\'\n\x04\x62lob\x18\x01 \x01(\x0b\x32\x19.tensorboard.service.Blob\"G\n\x0c\x42lobSequence\x12\x37\n\x07\x65ntries\x18\x01 \x03(\x0b\x32&.tensorboard.service.BlobSequenceEntry*W\n\tBlobState\x12\x16\n\x12\x42LOB_STATE_UNKNOWN\x10\x00\x12\x1a\n\x16\x42LOB_STATE_UNFINALIZED\x10\x01\x12\x16\n\x12\x42LOB_STATE_CURRENT\x10\x02\x62\x06proto3')

_BLOBSTATE = DESCRIPTOR.enum_types_by_name['BlobState']
BlobState = enum_type_wrapper.EnumTypeWrapper(_BLOBSTATE)
BLOB_STATE_UNKNOWN = 0
BLOB_STATE_UNFINALIZED = 1
BLOB_STATE_CURRENT = 2


_BLOB = DESCRIPTOR.message_types_by_name['Blob']
_BLOBSEQUENCEENTRY = DESCRIPTOR.message_types_by_name['BlobSequenceEntry']
_BLOBSEQUENCE = DESCRIPTOR.message_types_by_name['BlobSequence']
Blob = _reflection.GeneratedProtocolMessageType('Blob', (_message.Message,), {
  'DESCRIPTOR' : _BLOB,
  '__module__' : 'tensorboard.uploader.proto.blob_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.Blob)
  })
_sym_db.RegisterMessage(Blob)

BlobSequenceEntry = _reflection.GeneratedProtocolMessageType('BlobSequenceEntry', (_message.Message,), {
  'DESCRIPTOR' : _BLOBSEQUENCEENTRY,
  '__module__' : 'tensorboard.uploader.proto.blob_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.BlobSequenceEntry)
  })
_sym_db.RegisterMessage(BlobSequenceEntry)

BlobSequence = _reflection.GeneratedProtocolMessageType('BlobSequence', (_message.Message,), {
  'DESCRIPTOR' : _BLOBSEQUENCE,
  '__module__' : 'tensorboard.uploader.proto.blob_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.BlobSequence)
  })
_sym_db.RegisterMessage(BlobSequence)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BLOBSTATE._serialized_start=269
  _BLOBSTATE._serialized_end=356
  _BLOB._serialized_start=62
  _BLOB._serialized_end=132
  _BLOBSEQUENCEENTRY._serialized_start=134
  _BLOBSEQUENCEENTRY._serialized_end=194
  _BLOBSEQUENCE._serialized_start=196
  _BLOBSEQUENCE._serialized_end=267
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from tensorboard.data.proto import data_provider_pb2 as tensorboard_dot_data_dot_proto_dot_data__provider__pb2


class TensorBoardDataProviderStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetExperiment = channel.unary_unary(
                '/tensorboard.data.TensorBoardDataProvider/GetExperiment',
                request_serializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.GetExperimentRequest.SerializeToString,
                response_deserializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.GetExperimentResponse.FromString,
                )
        self.ListPlugins = channel.unary_unary(
                '/tensorboard.data.TensorBoardDataProvider/ListPlugins',
                request_serializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListPluginsRequest.SerializeToString,
                response_deserializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListPluginsResponse.FromString,
                )
        self.ListRuns = channel.unary_unary(
                '/tensorboard.data.TensorBoardDataProvider/ListRuns',
                request_serializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListRunsRequest.SerializeToString,
                response_deserializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListRunsResponse.FromString,
                )
        self.ListScalars = channel.unary_unary(
                '/tensorboard.data.TensorBoardDataProvider/ListScalars',
                request_serializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListScalarsRequest.SerializeToString,
                response_deserializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListScalarsResponse.FromString,
                )
        self.ReadScalars = channel.unary_unary(
                '/tensorboard.data.TensorBoardDataProvider/ReadScalars',
                request_serializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ReadScalarsRequest.SerializeToString,
                response_deserializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ReadScalarsResponse.FromString,
                )
        self.ListTensors = channel.unary_unary(
                '/tensorboard.data.TensorBoardDataProvider/ListTensors',
                request_serializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListTensorsRequest.SerializeToString,
                response_deserializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListTensorsResponse.FromString,
                )
        self.ReadTensors = channel.unary_unary(
                '/tensorboard.data.TensorBoardDataProvider/ReadTensors',
                request_serializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ReadTensorsRequest.SerializeToString,
                response_deserializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ReadTensorsResponse.FromString,
                )
        self.ListBlobSequences = channel.unary_unary(
                '/tensorboard.data.TensorBoardDataProvider/ListBlobSequences',
                request_serializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListBlobSequencesRequest.SerializeToString,
                response_deserializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListBlobSequencesResponse.FromString,
                )
        self.ReadBlobSequences = channel.unary_unary(
                '/tensorboard.data.TensorBoardDataProvider/ReadBlobSequences',
                request_serializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ReadBlobSequencesRequest.SerializeToString,
                response_deserializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ReadBlobSequencesResponse.FromString,
                )
        self.ReadBlob = channel.unary_stream(
                '/tensorboard.data.TensorBoardDataProvider/ReadBlob',
                request_serializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ReadBlobRequest.SerializeToString,
                response_deserializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ReadBlobResponse.FromString,
                )


class TensorBoardDataProviderServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetExperiment(self, request, context):
        """Get metadata about an experiment.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPlugins(self, request, context):
        """List plugins that have data for an experiment.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRuns(self, request, context):
        """List runs within an experiment.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListScalars(self, request, context):
        """List metadata about scalar time series.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadScalars(self, request, context):
        """Read data from scalar time series.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTensors(self, request, context):
        """List metadata about tensor time series.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadTensors(self, request, context):
        """Read data from tensor time series.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListBlobSequences(self, request, context):
        """List metadata about blob sequence time series.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadBlobSequences(self, request, context):
        """Read blob references from blob sequence time series. See `ReadBlob` to read
        the actual blob data.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadBlob(self, request, context):
        """Read data for a specific blob.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TensorBoardDataProviderServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetExperiment': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExperiment,
                    request_deserializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.GetExperimentRequest.FromString,
                    response_serializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.GetExperimentResponse.SerializeToString,
            ),
            'ListPlugins': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPlugins,
                    request_deserializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListPluginsRequest.FromString,
                    response_serializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListPluginsResponse.SerializeToString,
            ),
            'ListRuns': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRuns,
                    request_deserializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListRunsRequest.FromString,
                    response_serializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListRunsResponse.SerializeToString,
            ),
            'ListScalars': grpc.unary_unary_rpc_method_handler(
                    servicer.ListScalars,
                    request_deserializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListScalarsRequest.FromString,
                    response_serializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListScalarsResponse.SerializeToString,
            ),
            'ReadScalars': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadScalars,
                    request_deserializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ReadScalarsRequest.FromString,
                    response_serializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ReadScalarsResponse.SerializeToString,
            ),
            'ListTensors': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTensors,
                    request_deserializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListTensorsRequest.FromString,
                    response_serializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListTensorsResponse.SerializeToString,
            ),
            'ReadTensors': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadTensors,
                    request_deserializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ReadTensorsRequest.FromString,
                    response_serializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ReadTensorsResponse.SerializeToString,
            ),
            'ListBlobSequences': grpc.unary_unary_rpc_method_handler(
                    servicer.ListBlobSequences,
                    request_deserializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListBlobSequencesRequest.FromString,
                    response_serializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListBlobSequencesResponse.SerializeToString,
            ),
            'ReadBlobSequences': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadBlobSequences,
                    request_deserializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ReadBlobSequencesRequest.FromString,
                    response_serializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ReadBlobSequencesResponse.SerializeToString,
            ),
            'ReadBlob': grpc.unary_stream_rpc_method_handler(
                    servicer.ReadBlob,
                    request_deserializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ReadBlobRequest.FromString,
                    response_serializer=tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ReadBlobResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'tensorboard.data.TensorBoardDataProvider', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TensorBoardDataProvider(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetExperiment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tensorboard.data.TensorBoardDataProvider/GetExperiment',
            tensorboard_dot_data_dot_proto_dot_data__provider__pb2.GetExperimentRequest.SerializeToString,
            tensorboard_dot_data_dot_proto_dot_data__provider__pb2.GetExperimentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPlugins(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tensorboard.data.TensorBoardDataProvider/ListPlugins',
            tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListPluginsRequest.SerializeToString,
            tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListPluginsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListRuns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tensorboard.data.TensorBoardDataProvider/ListRuns',
            tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListRunsRequest.SerializeToString,
            tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListRunsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListScalars(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tensorboard.data.TensorBoardDataProvider/ListScalars',
            tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListScalarsRequest.SerializeToString,
            tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListScalarsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadScalars(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tensorboard.data.TensorBoardDataProvider/ReadScalars',
            tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ReadScalarsRequest.SerializeToString,
            tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ReadScalarsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListTensors(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tensorboard.data.TensorBoardDataProvider/ListTensors',
            tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListTensorsRequest.SerializeToString,
            tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListTensorsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadTensors(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tensorboard.data.TensorBoardDataProvider/ReadTensors',
            tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ReadTensorsRequest.SerializeToString,
            tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ReadTensorsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListBlobSequences(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tensorboard.data.TensorBoardDataProvider/ListBlobSequences',
            tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListBlobSequencesRequest.SerializeToString,
            tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ListBlobSequencesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadBlobSequences(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tensorboard.data.TensorBoardDataProvider/ReadBlobSequences',
            tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ReadBlobSequencesRequest.SerializeToString,
            tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ReadBlobSequencesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadBlob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/tensorboard.data.TensorBoardDataProvider/ReadBlob',
            tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ReadBlobRequest.SerializeToString,
            tensorboard_dot_data_dot_proto_dot_data__provider__pb2.ReadBlobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorboard/uploader/proto/experiment.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+tensorboard/uploader/proto/experiment.proto\x12\x13tensorboard.service\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa6\x02\n\nExperiment\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12/\n\x0b\x63reate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bupdate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bnum_scalars\x18\x04 \x01(\x03\x12\x10\n\x08num_runs\x18\x05 \x01(\x03\x12\x10\n\x08num_tags\x18\x06 \x01(\x03\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t\x12\x1a\n\x12total_tensor_bytes\x18\t \x01(\x03\x12\x18\n\x10total_blob_bytes\x18\n \x01(\x03\x12\r\n\x05owner\x18\x0b \x01(\t\"\xf0\x01\n\x0e\x45xperimentMask\x12\x13\n\x0b\x63reate_time\x18\x02 \x01(\x08\x12\x13\n\x0bupdate_time\x18\x03 \x01(\x08\x12\x13\n\x0bnum_scalars\x18\x04 \x01(\x08\x12\x10\n\x08num_runs\x18\x05 \x01(\x08\x12\x10\n\x08num_tags\x18\x06 \x01(\x08\x12\x0c\n\x04name\x18\x07 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\x08\x12\x1a\n\x12total_tensor_bytes\x18\t \x01(\x08\x12\x18\n\x10total_blob_bytes\x18\n \x01(\x08\x12\r\n\x05owner\x18\x0b \x01(\x08J\x04\x08\x01\x10\x02R\rexperiment_idb\x06proto3')



_EXPERIMENT = DESCRIPTOR.message_types_by_name['Experiment']
_EXPERIMENTMASK = DESCRIPTOR.message_types_by_name['ExperimentMask']
Experiment = _reflection.GeneratedProtocolMessageType('Experiment', (_message.Message,), {
  'DESCRIPTOR' : _EXPERIMENT,
  '__module__' : 'tensorboard.uploader.proto.experiment_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.Experiment)
  })
_sym_db.RegisterMessage(Experiment)

ExperimentMask = _reflection.GeneratedProtocolMessageType('ExperimentMask', (_message.Message,), {
  'DESCRIPTOR' : _EXPERIMENTMASK,
  '__module__' : 'tensorboard.uploader.proto.experiment_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.ExperimentMask)
  })
_sym_db.RegisterMessage(ExperimentMask)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _EXPERIMENT._serialized_start=102
  _EXPERIMENT._serialized_end=396
  _EXPERIMENTMASK._serialized_start=399
  _EXPERIMENTMASK._serialized_end=639
# @@protoc_insertion_point(module_scope)



# Copyright 2020 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
"""Dry-run stubs for various rpc services."""


from tensorboard.uploader.proto import write_service_pb2


class DryRunTensorBoardWriterStub:
    """A dry-run TensorBoardWriter gRPC Server.

    Only the methods used by the `tensorboard dev upload` are
    mocked out in this class.

    When additional methods start to be used by the command,
    their mocks should be added to this class.
    """

    def CreateExperiment(self, request, **kwargs):
        """Create a new experiment and remember it has been created."""
        del request, kwargs  # Unused.
        return write_service_pb2.CreateExperimentResponse()

    def WriteScalar(self, request, **kwargs):
        del request, kwargs  # Unused.
        return write_service_pb2.WriteScalarResponse()

    def WriteTensor(self, request, **kwargs):
        del request, kwargs  # Unused.
        return write_service_pb2.WriteTensorResponse()

    def GetOrCreateBlobSequence(self, request, **kwargs):
        del request, kwargs  # Unused.
        return write_service_pb2.GetOrCreateBlobSequenceResponse(
            blob_sequence_id="dummy_blob_sequence_id"
        )

    def WriteBlob(self, request, **kwargs):
        del kwargs  # Unused.
        for item in request:
            yield write_service_pb2.WriteBlobResponse()



# Copyright 2019 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
"""Information on the graph plugin."""


# This name is used as the plugin prefix route and to identify this plugin
# generally, and is also the `plugin_name` for run graphs after data-compat
# transformations.
PLUGIN_NAME = "graphs"
# The Summary API is implemented in TensorFlow because it uses TensorFlow internal APIs.
# As a result, this SummaryMetadata is a bit unconventional and uses non-public
# hardcoded name as the plugin name. Please refer to link below for the summary ops.
# https://github.com/tensorflow/tensorflow/blob/11f4ecb54708865ec757ca64e4805957b05d7570/tensorflow/python/ops/summary_ops_v2.py#L757
PLUGIN_NAME_RUN_METADATA = "graph_run_metadata"
# https://github.com/tensorflow/tensorflow/blob/11f4ecb54708865ec757ca64e4805957b05d7570/tensorflow/python/ops/summary_ops_v2.py#L788
PLUGIN_NAME_RUN_METADATA_WITH_GRAPH = "graph_run_metadata_graph"
# https://github.com/tensorflow/tensorflow/blob/565952cc2f17fdfd995e25171cf07be0f6f06180/tensorflow/python/ops/summary_ops_v2.py#L825
PLUGIN_NAME_KERAS_MODEL = "graph_keras_model"
# Plugin name used for `Event.tagged_run_metadata`. This doesn't fall into one
# of the above cases because (despite the name) `PLUGIN_NAME_RUN_METADATA` is
# _required_ to have both profile and op graphs, whereas tagged run metadata
# need only have profile data.
PLUGIN_NAME_TAGGED_RUN_METADATA = "graph_tagged_run_metadata"

# In the context of the data provider interface, tag name given to a
# graph read from the `graph_def` field of an `Event` proto, which is
# not attached to a summary and thus does not have a proper tag name of
# its own. Run level graphs always represent `GraphDef`s (graphs of
# TensorFlow ops), never conceptual graphs, profile graphs, etc. This is
# the only tag name used by the `"graphs"` plugin.
RUN_GRAPH_NAME = "__run_graph__"



# Copyright 2017 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
"""Image summaries and TensorFlow operations to create them.

An image summary stores the width, height, and PNG-encoded data for zero
or more images in a rank-1 string array: `[w, h, png0, png1, ...]`.

NOTE: This module is in beta, and its API is subject to change, but the
data that it stores to disk will be supported forever.
"""


import numpy as np

from tensorboard.plugins.image import metadata
from tensorboard.plugins.image import summary_v2
from tensorboard.util import encoder


# Export V2 versions.
image = summary_v2.image


def op(
    name,
    images,
    max_outputs=3,
    display_name=None,
    description=None,
    collections=None,
):
    """Create a legacy image summary op for use in a TensorFlow graph.

    Arguments:
      name: A unique name for the generated summary node.
      images: A `Tensor` representing pixel data with shape `[k, h, w, c]`,
        where `k` is the number of images, `h` and `w` are the height and
        width of the images, and `c` is the number of channels, which
        should be 1, 3, or 4. Any of the dimensions may be statically
        unknown (i.e., `None`).
      max_outputs: Optional `int` or rank-0 integer `Tensor`. At most this
        many images will be emitted at each step. When more than
        `max_outputs` many images are provided, the first `max_outputs` many
        images will be used and the rest silently discarded.
      display_name: Optional name for this summary in TensorBoard, as a
        constant `str`. Defaults to `name`.
      description: Optional long-form description for this summary, as a
        constant `str`. Markdown is supported. Defaults to empty.
      collections: Optional list of graph collections keys. The new
        summary op is added to these collections. Defaults to
        `[Graph Keys.SUMMARIES]`.

    Returns:
      A TensorFlow summary op.
    """
    # TODO(nickfelt): remove on-demand imports once dep situation is fixed.
    import tensorflow.compat.v1 as tf

    if display_name is None:
        display_name = name
    summary_metadata = metadata.create_summary_metadata(
        display_name=display_name, description=description
    )
    with tf.name_scope(name), tf.control_dependencies(
        [
            tf.assert_rank(images, 4),
            tf.assert_type(images, tf.uint8),
            tf.assert_non_negative(max_outputs),
        ]
    ):
        limited_images = images[:max_outputs]
        encoded_images = tf.map_fn(
            tf.image.encode_png,
            limited_images,
            dtype=tf.string,
            name="encode_each_image",
        )
        image_shape = tf.shape(input=images)
        dimensions = tf.stack(
            [
                tf.as_string(image_shape[2], name="width"),
                tf.as_string(image_shape[1], name="height"),
            ],
            name="dimensions",
        )
        tensor = tf.concat([dimensions, encoded_images], axis=0)
        return tf.summary.tensor_summary(
            name="image_summary",
            tensor=tensor,
            collections=collections,
            summary_metadata=summary_metadata,
        )


def pb(name, images, max_outputs=3, display_name=None, description=None):
    """Create a legacy image summary protobuf.

    This behaves as if you were to create an `op` with the same arguments
    (wrapped with constant tensors where appropriate) and then execute
    that summary op in a TensorFlow session.

    Arguments:
      name: A unique name for the generated summary, including any desired
        name scopes.
      images: An `np.array` representing pixel data with shape
        `[k, h, w, c]`, where `k` is the number of images, `w` and `h` are
        the width and height of the images, and `c` is the number of
        channels, which should be 1, 3, or 4.
      max_outputs: Optional `int`. At most this many images will be
        emitted. If more than this many images are provided, the first
        `max_outputs` many images will be used and the rest silently
        discarded.
      display_name: Optional name for this summary in TensorBoard, as a
        `str`. Defaults to `name`.
      description: Optional long-form description for this summary, as a
        `str`. Markdown is supported. Defaults to empty.

    Returns:
      A `tf.Summary` protobuf object.
    """
    # TODO(nickfelt): remove on-demand imports once dep situation is fixed.
    import tensorflow.compat.v1 as tf

    images = np.array(images).astype(np.uint8)
    if images.ndim != 4:
        raise ValueError("Shape %r must have rank 4" % (images.shape,))

    limited_images = images[:max_outputs]
    encoded_images = [encoder.encode_png(image) for image in limited_images]
    (width, height) = (images.shape[2], images.shape[1])
    content = [str(width), str(height)] + encoded_images
    tensor = tf.make_tensor_proto(content, dtype=tf.string)

    if display_name is None:
        display_name = name
    summary_metadata = metadata.create_summary_metadata(
        display_name=display_name, description=description
    )
    tf_summary_metadata = tf.SummaryMetadata.FromString(
        summary_metadata.SerializeToString()
    )

    summary = tf.Summary()
    summary.value.add(
        tag="%s/image_summary" % name,
        metadata=tf_summary_metadata,
        tensor=tensor,
    )
    return summary



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorboard/plugins/hparams/api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%tensorboard/plugins/hparams/api.proto\x12\x13tensorboard.hparams\x1a\x1cgoogle/protobuf/struct.proto\"\xc6\x01\n\nExperiment\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0c\n\x04user\x18\x02 \x01(\t\x12\x19\n\x11time_created_secs\x18\x03 \x01(\x01\x12\x35\n\x0chparam_infos\x18\x04 \x03(\x0b\x32\x1f.tensorboard.hparams.HParamInfo\x12\x35\n\x0cmetric_infos\x18\x05 \x03(\x0b\x32\x1f.tensorboard.hparams.MetricInfo\"\xed\x01\n\nHParamInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12+\n\x04type\x18\x04 \x01(\x0e\x32\x1d.tensorboard.hparams.DataType\x12\x35\n\x0f\x64omain_discrete\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.ListValueH\x00\x12\x38\n\x0f\x64omain_interval\x18\x06 \x01(\x0b\x32\x1d.tensorboard.hparams.IntervalH\x00\x42\x08\n\x06\x64omain\"0\n\x08Interval\x12\x11\n\tmin_value\x18\x01 \x01(\x01\x12\x11\n\tmax_value\x18\x02 \x01(\x01\"(\n\nMetricName\x12\r\n\x05group\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\"\x9e\x01\n\nMetricInfo\x12-\n\x04name\x18\x01 \x01(\x0b\x32\x1f.tensorboard.hparams.MetricName\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x36\n\x0c\x64\x61taset_type\x18\x05 \x01(\x0e\x32 .tensorboard.hparams.DatasetType\"\xa3\x02\n\x0cSessionGroup\x12\x0c\n\x04name\x18\x01 \x01(\t\x12?\n\x07hparams\x18\x02 \x03(\x0b\x32..tensorboard.hparams.SessionGroup.HparamsEntry\x12\x37\n\rmetric_values\x18\x03 \x03(\x0b\x32 .tensorboard.hparams.MetricValue\x12.\n\x08sessions\x18\x04 \x03(\x0b\x32\x1c.tensorboard.hparams.Session\x12\x13\n\x0bmonitor_url\x18\x05 \x01(\t\x1a\x46\n\x0cHparamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value:\x02\x38\x01\"z\n\x0bMetricValue\x12-\n\x04name\x18\x01 \x01(\x0b\x32\x1f.tensorboard.hparams.MetricName\x12\r\n\x05value\x18\x02 \x01(\x01\x12\x15\n\rtraining_step\x18\x03 \x01(\x05\x12\x16\n\x0ewall_time_secs\x18\x04 \x01(\x01\"\xd5\x01\n\x07Session\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0fstart_time_secs\x18\x02 \x01(\x01\x12\x15\n\rend_time_secs\x18\x03 \x01(\x01\x12+\n\x06status\x18\x04 \x01(\x0e\x32\x1b.tensorboard.hparams.Status\x12\x11\n\tmodel_uri\x18\x05 \x01(\t\x12\x37\n\rmetric_values\x18\x06 \x03(\x0b\x32 .tensorboard.hparams.MetricValue\x12\x13\n\x0bmonitor_url\x18\x07 \x01(\t\"/\n\x14GetExperimentRequest\x12\x17\n\x0f\x65xperiment_name\x18\x01 \x01(\t\"\xc4\x02\n\x18ListSessionGroupsRequest\x12\x17\n\x0f\x65xperiment_name\x18\x06 \x01(\t\x12\x35\n\x10\x61llowed_statuses\x18\x07 \x03(\x0e\x32\x1b.tensorboard.hparams.Status\x12\x32\n\ncol_params\x18\x01 \x03(\x0b\x32\x1e.tensorboard.hparams.ColParams\x12>\n\x10\x61ggregation_type\x18\x02 \x01(\x0e\x32$.tensorboard.hparams.AggregationType\x12;\n\x12\x61ggregation_metric\x18\x03 \x01(\x0b\x32\x1f.tensorboard.hparams.MetricName\x12\x13\n\x0bstart_index\x18\x04 \x01(\x05\x12\x12\n\nslice_size\x18\x05 \x01(\x05\"\xd9\x02\n\tColParams\x12\x31\n\x06metric\x18\x01 \x01(\x0b\x32\x1f.tensorboard.hparams.MetricNameH\x00\x12\x10\n\x06hparam\x18\x02 \x01(\tH\x00\x12-\n\x05order\x18\x03 \x01(\x0e\x32\x1e.tensorboard.hparams.SortOrder\x12\x1c\n\x14missing_values_first\x18\x04 \x01(\x08\x12\x17\n\rfilter_regexp\x18\x05 \x01(\tH\x01\x12\x38\n\x0f\x66ilter_interval\x18\x06 \x01(\x0b\x32\x1d.tensorboard.hparams.IntervalH\x01\x12\x35\n\x0f\x66ilter_discrete\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.ListValueH\x01\x12\x1e\n\x16\x65xclude_missing_values\x18\x08 \x01(\x08\x42\x06\n\x04nameB\x08\n\x06\x66ilter\"j\n\x19ListSessionGroupsResponse\x12\x39\n\x0esession_groups\x18\x01 \x03(\x0b\x32!.tensorboard.hparams.SessionGroup\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"}\n\x16ListMetricEvalsRequest\x12\x17\n\x0f\x65xperiment_name\x18\x03 \x01(\t\x12\x14\n\x0csession_name\x18\x01 \x01(\t\x12\x34\n\x0bmetric_name\x18\x02 \x01(\x0b\x32\x1f.tensorboard.hparams.MetricName*`\n\x08\x44\x61taType\x12\x13\n\x0f\x44\x41TA_TYPE_UNSET\x10\x00\x12\x14\n\x10\x44\x41TA_TYPE_STRING\x10\x01\x12\x12\n\x0e\x44\x41TA_TYPE_BOOL\x10\x02\x12\x15\n\x11\x44\x41TA_TYPE_FLOAT64\x10\x03*P\n\x0b\x44\x61tasetType\x12\x13\n\x0f\x44\x41TASET_UNKNOWN\x10\x00\x12\x14\n\x10\x44\x41TASET_TRAINING\x10\x01\x12\x16\n\x12\x44\x41TASET_VALIDATION\x10\x02*X\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x12\n\x0eSTATUS_SUCCESS\x10\x01\x12\x12\n\x0eSTATUS_FAILURE\x10\x02\x12\x12\n\x0eSTATUS_RUNNING\x10\x03*A\n\tSortOrder\x12\x15\n\x11ORDER_UNSPECIFIED\x10\x00\x12\r\n\tORDER_ASC\x10\x01\x12\x0e\n\nORDER_DESC\x10\x02*\x7f\n\x0f\x41ggregationType\x12\x15\n\x11\x41GGREGATION_UNSET\x10\x00\x12\x13\n\x0f\x41GGREGATION_AVG\x10\x01\x12\x16\n\x12\x41GGREGATION_MEDIAN\x10\x02\x12\x13\n\x0f\x41GGREGATION_MIN\x10\x03\x12\x13\n\x0f\x41GGREGATION_MAX\x10\x04\x62\x06proto3')

_DATATYPE = DESCRIPTOR.enum_types_by_name['DataType']
DataType = enum_type_wrapper.EnumTypeWrapper(_DATATYPE)
_DATASETTYPE = DESCRIPTOR.enum_types_by_name['DatasetType']
DatasetType = enum_type_wrapper.EnumTypeWrapper(_DATASETTYPE)
_STATUS = DESCRIPTOR.enum_types_by_name['Status']
Status = enum_type_wrapper.EnumTypeWrapper(_STATUS)
_SORTORDER = DESCRIPTOR.enum_types_by_name['SortOrder']
SortOrder = enum_type_wrapper.EnumTypeWrapper(_SORTORDER)
_AGGREGATIONTYPE = DESCRIPTOR.enum_types_by_name['AggregationType']
AggregationType = enum_type_wrapper.EnumTypeWrapper(_AGGREGATIONTYPE)
DATA_TYPE_UNSET = 0
DATA_TYPE_STRING = 1
DATA_TYPE_BOOL = 2
DATA_TYPE_FLOAT64 = 3
DATASET_UNKNOWN = 0
DATASET_TRAINING = 1
DATASET_VALIDATION = 2
STATUS_UNKNOWN = 0
STATUS_SUCCESS = 1
STATUS_FAILURE = 2
STATUS_RUNNING = 3
ORDER_UNSPECIFIED = 0
ORDER_ASC = 1
ORDER_DESC = 2
AGGREGATION_UNSET = 0
AGGREGATION_AVG = 1
AGGREGATION_MEDIAN = 2
AGGREGATION_MIN = 3
AGGREGATION_MAX = 4


_EXPERIMENT = DESCRIPTOR.message_types_by_name['Experiment']
_HPARAMINFO = DESCRIPTOR.message_types_by_name['HParamInfo']
_INTERVAL = DESCRIPTOR.message_types_by_name['Interval']
_METRICNAME = DESCRIPTOR.message_types_by_name['MetricName']
_METRICINFO = DESCRIPTOR.message_types_by_name['MetricInfo']
_SESSIONGROUP = DESCRIPTOR.message_types_by_name['SessionGroup']
_SESSIONGROUP_HPARAMSENTRY = _SESSIONGROUP.nested_types_by_name['HparamsEntry']
_METRICVALUE = DESCRIPTOR.message_types_by_name['MetricValue']
_SESSION = DESCRIPTOR.message_types_by_name['Session']
_GETEXPERIMENTREQUEST = DESCRIPTOR.message_types_by_name['GetExperimentRequest']
_LISTSESSIONGROUPSREQUEST = DESCRIPTOR.message_types_by_name['ListSessionGroupsRequest']
_COLPARAMS = DESCRIPTOR.message_types_by_name['ColParams']
_LISTSESSIONGROUPSRESPONSE = DESCRIPTOR.message_types_by_name['ListSessionGroupsResponse']
_LISTMETRICEVALSREQUEST = DESCRIPTOR.message_types_by_name['ListMetricEvalsRequest']
Experiment = _reflection.GeneratedProtocolMessageType('Experiment', (_message.Message,), {
  'DESCRIPTOR' : _EXPERIMENT,
  '__module__' : 'tensorboard.plugins.hparams.api_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.hparams.Experiment)
  })
_sym_db.RegisterMessage(Experiment)

HParamInfo = _reflection.GeneratedProtocolMessageType('HParamInfo', (_message.Message,), {
  'DESCRIPTOR' : _HPARAMINFO,
  '__module__' : 'tensorboard.plugins.hparams.api_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.hparams.HParamInfo)
  })
_sym_db.RegisterMessage(HParamInfo)

Interval = _reflection.GeneratedProtocolMessageType('Interval', (_message.Message,), {
  'DESCRIPTOR' : _INTERVAL,
  '__module__' : 'tensorboard.plugins.hparams.api_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.hparams.Interval)
  })
_sym_db.RegisterMessage(Interval)

MetricName = _reflection.GeneratedProtocolMessageType('MetricName', (_message.Message,), {
  'DESCRIPTOR' : _METRICNAME,
  '__module__' : 'tensorboard.plugins.hparams.api_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.hparams.MetricName)
  })
_sym_db.RegisterMessage(MetricName)

MetricInfo = _reflection.GeneratedProtocolMessageType('MetricInfo', (_message.Message,), {
  'DESCRIPTOR' : _METRICINFO,
  '__module__' : 'tensorboard.plugins.hparams.api_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.hparams.MetricInfo)
  })
_sym_db.RegisterMessage(MetricInfo)

SessionGroup = _reflection.GeneratedProtocolMessageType('SessionGroup', (_message.Message,), {

  'HparamsEntry' : _reflection.GeneratedProtocolMessageType('HparamsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SESSIONGROUP_HPARAMSENTRY,
    '__module__' : 'tensorboard.plugins.hparams.api_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.hparams.SessionGroup.HparamsEntry)
    })
  ,
  'DESCRIPTOR' : _SESSIONGROUP,
  '__module__' : 'tensorboard.plugins.hparams.api_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.hparams.SessionGroup)
  })
_sym_db.RegisterMessage(SessionGroup)
_sym_db.RegisterMessage(SessionGroup.HparamsEntry)

MetricValue = _reflection.GeneratedProtocolMessageType('MetricValue', (_message.Message,), {
  'DESCRIPTOR' : _METRICVALUE,
  '__module__' : 'tensorboard.plugins.hparams.api_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.hparams.MetricValue)
  })
_sym_db.RegisterMessage(MetricValue)

Session = _reflection.GeneratedProtocolMessageType('Session', (_message.Message,), {
  'DESCRIPTOR' : _SESSION,
  '__module__' : 'tensorboard.plugins.hparams.api_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.hparams.Session)
  })
_sym_db.RegisterMessage(Session)

GetExperimentRequest = _reflection.GeneratedProtocolMessageType('GetExperimentRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETEXPERIMENTREQUEST,
  '__module__' : 'tensorboard.plugins.hparams.api_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.hparams.GetExperimentRequest)
  })
_sym_db.RegisterMessage(GetExperimentRequest)

ListSessionGroupsRequest = _reflection.GeneratedProtocolMessageType('ListSessionGroupsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSESSIONGROUPSREQUEST,
  '__module__' : 'tensorboard.plugins.hparams.api_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.hparams.ListSessionGroupsRequest)
  })
_sym_db.RegisterMessage(ListSessionGroupsRequest)

ColParams = _reflection.GeneratedProtocolMessageType('ColParams', (_message.Message,), {
  'DESCRIPTOR' : _COLPARAMS,
  '__module__' : 'tensorboard.plugins.hparams.api_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.hparams.ColParams)
  })
_sym_db.RegisterMessage(ColParams)

ListSessionGroupsResponse = _reflection.GeneratedProtocolMessageType('ListSessionGroupsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSESSIONGROUPSRESPONSE,
  '__module__' : 'tensorboard.plugins.hparams.api_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.hparams.ListSessionGroupsResponse)
  })
_sym_db.RegisterMessage(ListSessionGroupsResponse)

ListMetricEvalsRequest = _reflection.GeneratedProtocolMessageType('ListMetricEvalsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMETRICEVALSREQUEST,
  '__module__' : 'tensorboard.plugins.hparams.api_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.hparams.ListMetricEvalsRequest)
  })
_sym_db.RegisterMessage(ListMetricEvalsRequest)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSIONGROUP_HPARAMSENTRY._options = None
  _SESSIONGROUP_HPARAMSENTRY._serialized_options = b'8\001'
  _DATATYPE._serialized_start=2379
  _DATATYPE._serialized_end=2475
  _DATASETTYPE._serialized_start=2477
  _DATASETTYPE._serialized_end=2557
  _STATUS._serialized_start=2559
  _STATUS._serialized_end=2647
  _SORTORDER._serialized_start=2649
  _SORTORDER._serialized_end=2714
  _AGGREGATIONTYPE._serialized_start=2716
  _AGGREGATIONTYPE._serialized_end=2843
  _EXPERIMENT._serialized_start=93
  _EXPERIMENT._serialized_end=291
  _HPARAMINFO._serialized_start=294
  _HPARAMINFO._serialized_end=531
  _INTERVAL._serialized_start=533
  _INTERVAL._serialized_end=581
  _METRICNAME._serialized_start=583
  _METRICNAME._serialized_end=623
  _METRICINFO._serialized_start=626
  _METRICINFO._serialized_end=784
  _SESSIONGROUP._serialized_start=787
  _SESSIONGROUP._serialized_end=1078
  _SESSIONGROUP_HPARAMSENTRY._serialized_start=1008
  _SESSIONGROUP_HPARAMSENTRY._serialized_end=1078
  _METRICVALUE._serialized_start=1080
  _METRICVALUE._serialized_end=1202
  _SESSION._serialized_start=1205
  _SESSION._serialized_end=1418
  _GETEXPERIMENTREQUEST._serialized_start=1420
  _GETEXPERIMENTREQUEST._serialized_end=1467
  _LISTSESSIONGROUPSREQUEST._serialized_start=1470
  _LISTSESSIONGROUPSREQUEST._serialized_end=1794
  _COLPARAMS._serialized_start=1797
  _COLPARAMS._serialized_end=2142
  _LISTSESSIONGROUPSRESPONSE._serialized_start=2144
  _LISTSESSIONGROUPSRESPONSE._serialized_end=2250
  _LISTMETRICEVALSREQUEST._serialized_start=2252
  _LISTMETRICEVALSREQUEST._serialized_end=2377
# @@protoc_insertion_point(module_scope)



# Copyright 2015 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
"""Functions for Python 2 vs. 3 compatibility.

## Conversion routines
In addition to the functions below, `as_str` converts an object to a `str`.


## Types
The compatibility module also provides the following types:

* `bytes_or_text_types`
* `complex_types`
* `integral_types`
* `real_types`
"""


import numbers as _numbers
import numpy as _np

from tensorboard.compat.tensorflow_stub.compat.v1 import *  # noqa


def as_bytes(bytes_or_text, encoding="utf-8"):
    """Converts either bytes or unicode to `bytes`, using utf-8 encoding for
    text.

    Args:
    bytes_or_text: A `bytes`, `str`, or `unicode` object.
    encoding: A string indicating the charset for encoding unicode.

    Returns:
    A `bytes` object.

    Raises:
    TypeError: If `bytes_or_text` is not a binary or unicode string.
    """
    if isinstance(bytes_or_text, str):
        return bytes_or_text.encode(encoding)
    elif isinstance(bytes_or_text, bytes):
        return bytes_or_text
    else:
        raise TypeError(
            "Expected binary or unicode string, got %r" % (bytes_or_text,)
        )


def as_text(bytes_or_text, encoding="utf-8"):
    """Returns the given argument as a unicode string.

    Args:
    bytes_or_text: A `bytes`, `str`, or `unicode` object.
    encoding: A string indicating the charset for decoding unicode.

    Returns:
    A `unicode` (Python 2) or `str` (Python 3) object.

    Raises:
    TypeError: If `bytes_or_text` is not a binary or unicode string.
    """
    if isinstance(bytes_or_text, str):
        return bytes_or_text
    elif isinstance(bytes_or_text, bytes):
        return bytes_or_text.decode(encoding)
    else:
        raise TypeError(
            "Expected binary or unicode string, got %r" % bytes_or_text
        )


# Convert an object to a `str` in both Python 2 and 3.
as_str = as_text


# @tf_export('compat.as_str_any')
def as_str_any(value):
    """Converts to `str` as `str(value)`, but use `as_str` for `bytes`.

    Args:
    value: A object that can be converted to `str`.

    Returns:
    A `str` object.
    """
    if isinstance(value, bytes):
        return as_str(value)
    else:
        return str(value)


# @tf_export('compat.path_to_str')
def path_to_str(path):
    """Returns the file system path representation of a `PathLike` object, else
    as it is.

    Args:
    path: An object that can be converted to path representation.

    Returns:
    A `str` object.
    """
    if hasattr(path, "__fspath__"):
        path = as_str_any(path.__fspath__())
    return path


# Numpy 1.8 scalars don't inherit from numbers.Integral in Python 3, so we
# need to check them specifically.  The same goes from Real and Complex.
integral_types = (_numbers.Integral, _np.integer)
# tf_export('compat.integral_types').export_constant(__name__, 'integral_types')
real_types = (_numbers.Real, _np.integer, _np.floating)
# tf_export('compat.real_types').export_constant(__name__, 'real_types')
complex_types = (_numbers.Complex, _np.number)
# tf_export('compat.complex_types').export_constant(__name__, 'complex_types')

# Either bytes or text.
bytes_or_text_types = (bytes, str)
# tf_export('compat.bytes_or_text_types').export_constant(__name__,
#                                                         'bytes_or_text_types')



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorboard/compat/proto/step_stats.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tensorboard.compat.proto import allocation_description_pb2 as tensorboard_dot_compat_dot_proto_dot_allocation__description__pb2
from tensorboard.compat.proto import tensor_description_pb2 as tensorboard_dot_compat_dot_proto_dot_tensor__description__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)tensorboard/compat/proto/step_stats.proto\x12\x0btensorboard\x1a\x35tensorboard/compat/proto/allocation_description.proto\x1a\x31tensorboard/compat/proto/tensor_description.proto\"=\n\x10\x41llocationRecord\x12\x14\n\x0c\x61lloc_micros\x18\x01 \x01(\x03\x12\x13\n\x0b\x61lloc_bytes\x18\x02 \x01(\x03\"\xc5\x01\n\x13\x41llocatorMemoryUsed\x12\x16\n\x0e\x61llocator_name\x18\x01 \x01(\t\x12\x13\n\x0btotal_bytes\x18\x02 \x01(\x03\x12\x12\n\npeak_bytes\x18\x03 \x01(\x03\x12\x12\n\nlive_bytes\x18\x04 \x01(\x03\x12\x39\n\x12\x61llocation_records\x18\x06 \x03(\x0b\x32\x1d.tensorboard.AllocationRecord\x12\x1e\n\x16\x61llocator_bytes_in_use\x18\x05 \x01(\x03\"V\n\nNodeOutput\x12\x0c\n\x04slot\x18\x01 \x01(\x05\x12:\n\x12tensor_description\x18\x03 \x01(\x0b\x32\x1e.tensorboard.TensorDescription\"\xec\x01\n\x0bMemoryStats\x12\x18\n\x10temp_memory_size\x18\x01 \x01(\x03\x12\x1e\n\x16persistent_memory_size\x18\x03 \x01(\x03\x12#\n\x1bpersistent_tensor_alloc_ids\x18\x05 \x03(\x03\x12#\n\x17\x64\x65vice_temp_memory_size\x18\x02 \x01(\x03\x42\x02\x18\x01\x12)\n\x1d\x64\x65vice_persistent_memory_size\x18\x04 \x01(\x03\x42\x02\x18\x01\x12.\n\"device_persistent_tensor_alloc_ids\x18\x06 \x03(\x03\x42\x02\x18\x01\"\xa2\x04\n\rNodeExecStats\x12\x11\n\tnode_name\x18\x01 \x01(\t\x12\x18\n\x10\x61ll_start_micros\x18\x02 \x01(\x03\x12\x1b\n\x13op_start_rel_micros\x18\x03 \x01(\x03\x12\x19\n\x11op_end_rel_micros\x18\x04 \x01(\x03\x12\x1a\n\x12\x61ll_end_rel_micros\x18\x05 \x01(\x03\x12\x30\n\x06memory\x18\x06 \x03(\x0b\x32 .tensorboard.AllocatorMemoryUsed\x12\'\n\x06output\x18\x07 \x03(\x0b\x32\x17.tensorboard.NodeOutput\x12\x16\n\x0etimeline_label\x18\x08 \x01(\t\x12\x18\n\x10scheduled_micros\x18\t \x01(\x03\x12\x11\n\tthread_id\x18\n \x01(\r\x12=\n\x11referenced_tensor\x18\x0b \x03(\x0b\x32\".tensorboard.AllocationDescription\x12.\n\x0cmemory_stats\x18\x0c \x01(\x0b\x32\x18.tensorboard.MemoryStats\x12\x17\n\x0f\x61ll_start_nanos\x18\r \x01(\x03\x12\x1a\n\x12op_start_rel_nanos\x18\x0e \x01(\x03\x12\x18\n\x10op_end_rel_nanos\x18\x0f \x01(\x03\x12\x19\n\x11\x61ll_end_rel_nanos\x18\x10 \x01(\x03\x12\x17\n\x0fscheduled_nanos\x18\x11 \x01(\x03\"\xca\x01\n\x0f\x44\x65viceStepStats\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\t\x12.\n\nnode_stats\x18\x02 \x03(\x0b\x32\x1a.tensorboard.NodeExecStats\x12\x43\n\x0cthread_names\x18\x03 \x03(\x0b\x32-.tensorboard.DeviceStepStats.ThreadNamesEntry\x1a\x32\n\x10ThreadNamesEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"<\n\tStepStats\x12/\n\tdev_stats\x18\x01 \x03(\x0b\x32\x1c.tensorboard.DeviceStepStatsB\x83\x01\n\x18org.tensorflow.frameworkB\x0fStepStatsProtosP\x01ZQgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/step_stats_go_proto\xf8\x01\x01\x62\x06proto3')



_ALLOCATIONRECORD = DESCRIPTOR.message_types_by_name['AllocationRecord']
_ALLOCATORMEMORYUSED = DESCRIPTOR.message_types_by_name['AllocatorMemoryUsed']
_NODEOUTPUT = DESCRIPTOR.message_types_by_name['NodeOutput']
_MEMORYSTATS = DESCRIPTOR.message_types_by_name['MemoryStats']
_NODEEXECSTATS = DESCRIPTOR.message_types_by_name['NodeExecStats']
_DEVICESTEPSTATS = DESCRIPTOR.message_types_by_name['DeviceStepStats']
_DEVICESTEPSTATS_THREADNAMESENTRY = _DEVICESTEPSTATS.nested_types_by_name['ThreadNamesEntry']
_STEPSTATS = DESCRIPTOR.message_types_by_name['StepStats']
AllocationRecord = _reflection.GeneratedProtocolMessageType('AllocationRecord', (_message.Message,), {
  'DESCRIPTOR' : _ALLOCATIONRECORD,
  '__module__' : 'tensorboard.compat.proto.step_stats_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.AllocationRecord)
  })
_sym_db.RegisterMessage(AllocationRecord)

AllocatorMemoryUsed = _reflection.GeneratedProtocolMessageType('AllocatorMemoryUsed', (_message.Message,), {
  'DESCRIPTOR' : _ALLOCATORMEMORYUSED,
  '__module__' : 'tensorboard.compat.proto.step_stats_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.AllocatorMemoryUsed)
  })
_sym_db.RegisterMessage(AllocatorMemoryUsed)

NodeOutput = _reflection.GeneratedProtocolMessageType('NodeOutput', (_message.Message,), {
  'DESCRIPTOR' : _NODEOUTPUT,
  '__module__' : 'tensorboard.compat.proto.step_stats_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.NodeOutput)
  })
_sym_db.RegisterMessage(NodeOutput)

MemoryStats = _reflection.GeneratedProtocolMessageType('MemoryStats', (_message.Message,), {
  'DESCRIPTOR' : _MEMORYSTATS,
  '__module__' : 'tensorboard.compat.proto.step_stats_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.MemoryStats)
  })
_sym_db.RegisterMessage(MemoryStats)

NodeExecStats = _reflection.GeneratedProtocolMessageType('NodeExecStats', (_message.Message,), {
  'DESCRIPTOR' : _NODEEXECSTATS,
  '__module__' : 'tensorboard.compat.proto.step_stats_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.NodeExecStats)
  })
_sym_db.RegisterMessage(NodeExecStats)

DeviceStepStats = _reflection.GeneratedProtocolMessageType('DeviceStepStats', (_message.Message,), {

  'ThreadNamesEntry' : _reflection.GeneratedProtocolMessageType('ThreadNamesEntry', (_message.Message,), {
    'DESCRIPTOR' : _DEVICESTEPSTATS_THREADNAMESENTRY,
    '__module__' : 'tensorboard.compat.proto.step_stats_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.DeviceStepStats.ThreadNamesEntry)
    })
  ,
  'DESCRIPTOR' : _DEVICESTEPSTATS,
  '__module__' : 'tensorboard.compat.proto.step_stats_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.DeviceStepStats)
  })
_sym_db.RegisterMessage(DeviceStepStats)
_sym_db.RegisterMessage(DeviceStepStats.ThreadNamesEntry)

StepStats = _reflection.GeneratedProtocolMessageType('StepStats', (_message.Message,), {
  'DESCRIPTOR' : _STEPSTATS,
  '__module__' : 'tensorboard.compat.proto.step_stats_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.StepStats)
  })
_sym_db.RegisterMessage(StepStats)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030org.tensorflow.frameworkB\017StepStatsProtosP\001ZQgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/step_stats_go_proto\370\001\001'
  _MEMORYSTATS.fields_by_name['device_temp_memory_size']._options = None
  _MEMORYSTATS.fields_by_name['device_temp_memory_size']._serialized_options = b'\030\001'
  _MEMORYSTATS.fields_by_name['device_persistent_memory_size']._options = None
  _MEMORYSTATS.fields_by_name['device_persistent_memory_size']._serialized_options = b'\030\001'
  _MEMORYSTATS.fields_by_name['device_persistent_tensor_alloc_ids']._options = None
  _MEMORYSTATS.fields_by_name['device_persistent_tensor_alloc_ids']._serialized_options = b'\030\001'
  _DEVICESTEPSTATS_THREADNAMESENTRY._options = None
  _DEVICESTEPSTATS_THREADNAMESENTRY._serialized_options = b'8\001'
  _ALLOCATIONRECORD._serialized_start=164
  _ALLOCATIONRECORD._serialized_end=225
  _ALLOCATORMEMORYUSED._serialized_start=228
  _ALLOCATORMEMORYUSED._serialized_end=425
  _NODEOUTPUT._serialized_start=427
  _NODEOUTPUT._serialized_end=513
  _MEMORYSTATS._serialized_start=516
  _MEMORYSTATS._serialized_end=752
  _NODEEXECSTATS._serialized_start=755
  _NODEEXECSTATS._serialized_end=1301
  _DEVICESTEPSTATS._serialized_start=1304
  _DEVICESTEPSTATS._serialized_end=1506
  _DEVICESTEPSTATS_THREADNAMESENTRY._serialized_start=1456
  _DEVICESTEPSTATS_THREADNAMESENTRY._serialized_end=1506
  _STEPSTATS._serialized_start=1508
  _STEPSTATS._serialized_end=1568
# @@protoc_insertion_point(module_scope)



# Copyright 2018 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
"""Central API entry point for v2 versions of summary operations.

This module exposes v2 summary ops for the standard TensorBoard plugins.
"""

# pylint: disable=unused-import
from tensorboard.plugins.audio.summary_v2 import audio  # noqa: F401
from tensorboard.plugins.histogram.summary_v2 import histogram  # noqa: F401
from tensorboard.plugins.image.summary_v2 import image  # noqa: F401
from tensorboard.plugins.scalar.summary_v2 import scalar  # noqa: F401
from tensorboard.plugins.text.summary_v2 import text  # noqa: F401



# Copyright 2016 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
"""TensorBoard Plugin abstract base class.

Every plugin in TensorBoard must extend and implement the abstract
methods of this base class.
"""


from abc import ABCMeta
from abc import abstractmethod


class TBPlugin(metaclass=ABCMeta):
    """TensorBoard plugin interface.

    Every plugin must extend from this class.

    Subclasses should have a trivial constructor that takes a TBContext
    argument. Any operation that might throw an exception should either be
    done lazily or made safe with a TBLoader subclass, so the plugin won't
    negatively impact the rest of TensorBoard.

    Fields:
      plugin_name: The plugin_name will also be a prefix in the http
        handlers, e.g. `data/plugins/$PLUGIN_NAME/$HANDLER` The plugin
        name must be unique for each registered plugin, or a ValueError
        will be thrown when the application is constructed. The plugin
        name must only contain characters among [A-Za-z0-9_.-], and must
        be nonempty, or a ValueError will similarly be thrown.
    """

    plugin_name = None

    def __init__(self, context):
        """Initializes this plugin.

        The default implementation does nothing. Subclasses are encouraged
        to override this and save any necessary fields from the `context`.

        Args:
          context: A `base_plugin.TBContext` object.
        """
        pass

    @abstractmethod
    def get_plugin_apps(self):
        """Returns a set of WSGI applications that the plugin implements.

        Each application gets registered with the tensorboard app and is served
        under a prefix path that includes the name of the plugin.

        Returns:
          A dict mapping route paths to WSGI applications. Each route path
          should include a leading slash.
        """
        raise NotImplementedError()

    @abstractmethod
    def is_active(self):
        """Determines whether this plugin is active.

        A plugin may not be active for instance if it lacks relevant data. If a
        plugin is inactive, the frontend may avoid issuing requests to its routes.

        Returns:
          A boolean value. Whether this plugin is active.
        """
        raise NotImplementedError()

    def frontend_metadata(self):
        """Defines how the plugin will be displayed on the frontend.

        The base implementation returns a default value. Subclasses
        should override this and specify either an `es_module_path` or
        (for legacy plugins) an `element_name`, and are encouraged to
        set any other relevant attributes.
        """
        return FrontendMetadata()

    def data_plugin_names(self):
        """Experimental. Lists plugins whose summary data this plugin reads.

        Returns:
          A collection of strings representing plugin names (as read
          from `SummaryMetadata.plugin_data.plugin_name`) from which
          this plugin may read data. Defaults to `(self.plugin_name,)`.
        """
        return (self.plugin_name,)


class FrontendMetadata:
    """Metadata required to render a plugin on the frontend.

    Each argument to the constructor is publicly accessible under a
    field of the same name. See constructor docs for further details.
    """

    def __init__(
        self,
        *,
        disable_reload=None,
        element_name=None,
        es_module_path=None,
        remove_dom=None,
        tab_name=None,
        is_ng_component=None,
    ):
        """Creates a `FrontendMetadata` value.

        The argument list is sorted and may be extended in the future;
        therefore, callers must pass only named arguments to this
        constructor.

        Args:
          disable_reload: Whether to disable the reload button and
              auto-reload timer. A `bool`; defaults to `False`.
          element_name: For legacy plugins, name of the custom element
              defining the plugin frontend: e.g., `"tf-scalar-dashboard"`.
              A `str` or `None` (for iframed plugins). Mutually exclusive
              with `es_module_path`.
          es_module_path: ES module to use as an entry point to this plugin.
              A `str` that is a key in the result of `get_plugin_apps()`, or
              `None` for legacy plugins bundled with TensorBoard as part of
              `webfiles.zip`. Mutually exclusive with legacy `element_name`
          remove_dom: Whether to remove the plugin DOM when switching to a
              different plugin, to trigger the Polymer 'detached' event.
              A `bool`; defaults to `False`.
          tab_name: Name to show in the menu item for this dashboard within
              the navigation bar. May differ from the plugin name: for
              instance, the tab name should not use underscores to separate
              words. Should be a `str` or `None` (the default; indicates to
              use the plugin name as the tab name).
          is_ng_component: Set to `True` only for built-in Angular plugins.
              In this case, the `plugin_name` property of the Plugin, which is
              mapped to the `id` property in JavaScript's `UiPluginMetadata` type,
              is used to select the Angular component. A `True` value is mutually
              exclusive with `element_name` and `es_module_path`.
        """
        self._disable_reload = (
            False if disable_reload is None else disable_reload
        )
        self._element_name = element_name
        self._es_module_path = es_module_path
        self._remove_dom = False if remove_dom is None else remove_dom
        self._tab_name = tab_name
        self._is_ng_component = (
            False if is_ng_component is None else is_ng_component
        )

    @property
    def disable_reload(self):
        return self._disable_reload

    @property
    def element_name(self):
        return self._element_name

    @property
    def is_ng_component(self):
        return self._is_ng_component

    @property
    def es_module_path(self):
        return self._es_module_path

    @property
    def remove_dom(self):
        return self._remove_dom

    @property
    def tab_name(self):
        return self._tab_name

    def __eq__(self, other):
        if not isinstance(other, FrontendMetadata):
            return False
        if self._disable_reload != other._disable_reload:
            return False
        if self._disable_reload != other._disable_reload:
            return False
        if self._element_name != other._element_name:
            return False
        if self._es_module_path != other._es_module_path:
            return False
        if self._remove_dom != other._remove_dom:
            return False
        if self._tab_name != other._tab_name:
            return False
        return True

    def __hash__(self):
        return hash(
            (
                self._disable_reload,
                self._element_name,
                self._es_module_path,
                self._remove_dom,
                self._tab_name,
                self._is_ng_component,
            )
        )

    def __repr__(self):
        return "FrontendMetadata(%s)" % ", ".join(
            (
                "disable_reload=%r" % self._disable_reload,
                "element_name=%r" % self._element_name,
                "es_module_path=%r" % self._es_module_path,
                "remove_dom=%r" % self._remove_dom,
                "tab_name=%r" % self._tab_name,
                "is_ng_component=%r" % self._is_ng_component,
            )
        )


class TBContext:
    """Magic container of information passed from TensorBoard core to plugins.

    A TBContext instance is passed to the constructor of a TBPlugin class. Plugins
    are strongly encouraged to assume that any of these fields can be None. In
    cases when a field is considered mandatory by a plugin, it can either crash
    with ValueError, or silently choose to disable itself by returning False from
    its is_active method.

    All fields in this object are thread safe.
    """

    def __init__(
        self,
        *,
        assets_zip_provider=None,
        data_provider=None,
        flags=None,
        logdir=None,
        multiplexer=None,
        plugin_name_to_instance=None,
        sampling_hints=None,
        window_title=None,
    ):
        """Instantiates magic container.

        The argument list is sorted and may be extended in the future; therefore,
        callers must pass only named arguments to this constructor.

        Args:
          assets_zip_provider: A function that returns a newly opened file handle
              for a zip file containing all static assets. The file names inside the
              zip file are considered absolute paths on the web server. The file
              handle this function returns must be closed. It is assumed that you
              will pass this file handle to zipfile.ZipFile. This zip file should
              also have been created by the tensorboard_zip_file build rule.
          data_provider: Instance of `tensorboard.data.provider.DataProvider`. May
            be `None` if `flags.generic_data` is set to `"false"`.
          flags: An object of the runtime flags provided to TensorBoard to their
              values.
          logdir: The string logging directory TensorBoard was started with.
          multiplexer: An EventMultiplexer with underlying TB data. Plugins should
              copy this data over to the database when the db fields are set.
          plugin_name_to_instance: A mapping between plugin name to instance.
              Plugins may use this property to access other plugins. The context
              object is passed to plugins during their construction, so a given
              plugin may be absent from this mapping until it is registered. Plugin
              logic should handle cases in which a plugin is absent from this
              mapping, lest a KeyError is raised.
          sampling_hints: Map from plugin name to `int` or `NoneType`, where
              the value represents the user-specified downsampling limit as
              given to the `--samples_per_plugin` flag, or `None` if none was
              explicitly given for this plugin.
          window_title: A string specifying the window title.
        """
        self.assets_zip_provider = assets_zip_provider
        self.data_provider = data_provider
        self.flags = flags
        self.logdir = logdir
        self.multiplexer = multiplexer
        self.plugin_name_to_instance = plugin_name_to_instance
        self.sampling_hints = sampling_hints
        self.window_title = window_title


class TBLoader:
    """TBPlugin factory base class.

    Plugins can override this class to customize how a plugin is loaded at
    startup. This might entail adding command-line arguments, checking if
    optional dependencies are installed, and potentially also specializing
    the plugin class at runtime.

    When plugins use optional dependencies, the loader needs to be
    specified in its own module. That way it's guaranteed to be
    importable, even if the `TBPlugin` itself can't be imported.

    Subclasses must have trivial constructors.
    """

    def define_flags(self, parser):
        """Adds plugin-specific CLI flags to parser.

        The default behavior is to do nothing.

        When overriding this method, it's recommended that plugins call the
        `parser.add_argument_group(plugin_name)` method for readability. No
        flags should be specified that would cause `parse_args([])` to fail.

        Args:
          parser: The argument parsing object, which may be mutated.
        """
        pass

    def fix_flags(self, flags):
        """Allows flag values to be corrected or validated after parsing.

        Args:
          flags: The parsed argparse.Namespace object.

        Raises:
          base_plugin.FlagsError: If a flag is invalid or a required
              flag is not passed.
        """
        pass

    def load(self, context):
        """Loads a TBPlugin instance during the setup phase.

        Args:
          context: The TBContext instance.

        Returns:
          A plugin instance or None if it could not be loaded. Loaders that return
          None are skipped.

        :type context: TBContext
        :rtype: TBPlugin | None
        """
        return None


class BasicLoader(TBLoader):
    """Simple TBLoader that's sufficient for most plugins."""

    def __init__(self, plugin_class):
        """Creates simple plugin instance maker.

        :param plugin_class: :class:`TBPlugin`
        """
        self.plugin_class = plugin_class

    def load(self, context):
        return self.plugin_class(context)


class FlagsError(ValueError):
    """Raised when a command line flag is not specified or is invalid."""

    pass



# Copyright 2018 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
"""Central API entry point for summary operations.

This module exposes summary ops for the standard TensorBoard plugins.
"""

# If the V1 summary API is accessible, load and re-export it here.
try:
    from tensorboard.summary import v1  # noqa: F401
except ImportError:
    pass

# Load the V2 summary API if accessible.
try:
    from tensorboard.summary import v2  # noqa: F401
    from tensorboard.summary.v2 import *  # noqa: F401
except ImportError:
    pass

from tensorboard.summary._output import DirectoryOutput  # noqa: F401
from tensorboard.summary._output import Output  # noqa: F401
from tensorboard.summary._writer import Writer  # noqa: F401



# Copyright 2022 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
"""Middleware for injecting client-side feature flags into the Context."""

import json

from tensorboard import context
from tensorboard import errors


class ClientFeatureFlagsMiddleware:
    """Middleware for injecting client-side feature flags into the Context.

    The client webapp is expected to include a json-serialized version of its
    FeatureFlags in the `X-TensorBoard-Feature-Flags` header. This middleware
    extracts the header value and converts it into the client_feature_flags
    property for the DataProvider's Context object, where client_feature_flags
    is a Dict of string keys and arbitrary value types.
    """

    def __init__(self, application):
        """Initializes this middleware.

        Args:
          application: The WSGI application to wrap (see PEP 3333).
        """
        self._application = application

    def __call__(self, environ, start_response):
        possible_feature_flags = environ.get("HTTP_X_TENSORBOARD_FEATURE_FLAGS")
        if not possible_feature_flags:
            return self._application(environ, start_response)

        try:
            client_feature_flags = json.loads(possible_feature_flags)
        except json.JSONDecodeError:
            raise errors.InvalidArgumentError(
                "X-TensorBoard-Feature-Flags cannot be JSON decoded."
            )

        if not isinstance(client_feature_flags, dict):
            raise errors.InvalidArgumentError(
                "X-TensorBoard-Feature-Flags cannot be decoded to a dict."
            )

        ctx = context.from_environ(environ).replace(
            client_feature_flags=client_feature_flags
        )
        context.set_in_environ(environ, ctx)

        return self._application(environ, start_response)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorboard/uploader/proto/scalar.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tensorboard.compat.proto import summary_pb2 as tensorboard_dot_compat_dot_proto_dot_summary__pb2
try:
  tensorboard_dot_compat_dot_proto_dot_histogram__pb2 = tensorboard_dot_compat_dot_proto_dot_summary__pb2.tensorboard_dot_compat_dot_proto_dot_histogram__pb2
except AttributeError:
  tensorboard_dot_compat_dot_proto_dot_histogram__pb2 = tensorboard_dot_compat_dot_proto_dot_summary__pb2.tensorboard.compat.proto.histogram_pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'tensorboard/uploader/proto/scalar.proto\x12\x13tensorboard.service\x1a\x1fgoogle/protobuf/timestamp.proto\x1a&tensorboard/compat/proto/summary.proto\"Y\n\x0bScalarPoint\x12\x0c\n\x04step\x18\x01 \x01(\x03\x12-\n\twall_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05value\x18\x03 \x01(\x01\"\x92\x01\n\x13ScalarPointMetadata\x12\x10\n\x08max_step\x18\x01 \x01(\x03\x12\x31\n\rmax_wall_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x10summary_metadata\x18\x03 \x01(\x0b\x32\x1c.tensorboard.SummaryMetadatab\x06proto3')



_SCALARPOINT = DESCRIPTOR.message_types_by_name['ScalarPoint']
_SCALARPOINTMETADATA = DESCRIPTOR.message_types_by_name['ScalarPointMetadata']
ScalarPoint = _reflection.GeneratedProtocolMessageType('ScalarPoint', (_message.Message,), {
  'DESCRIPTOR' : _SCALARPOINT,
  '__module__' : 'tensorboard.uploader.proto.scalar_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.ScalarPoint)
  })
_sym_db.RegisterMessage(ScalarPoint)

ScalarPointMetadata = _reflection.GeneratedProtocolMessageType('ScalarPointMetadata', (_message.Message,), {
  'DESCRIPTOR' : _SCALARPOINTMETADATA,
  '__module__' : 'tensorboard.uploader.proto.scalar_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.ScalarPointMetadata)
  })
_sym_db.RegisterMessage(ScalarPointMetadata)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SCALARPOINT._serialized_start=137
  _SCALARPOINT._serialized_end=226
  _SCALARPOINTMETADATA._serialized_start=229
  _SCALARPOINTMETADATA._serialized_end=375
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorboard/data/proto/data_provider.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tensorboard.compat.proto import summary_pb2 as tensorboard_dot_compat_dot_proto_dot_summary__pb2
try:
  tensorboard_dot_compat_dot_proto_dot_histogram__pb2 = tensorboard_dot_compat_dot_proto_dot_summary__pb2.tensorboard_dot_compat_dot_proto_dot_histogram__pb2
except AttributeError:
  tensorboard_dot_compat_dot_proto_dot_histogram__pb2 = tensorboard_dot_compat_dot_proto_dot_summary__pb2.tensorboard.compat.proto.histogram_pb2
from tensorboard.compat.proto import tensor_pb2 as tensorboard_dot_compat_dot_proto_dot_tensor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*tensorboard/data/proto/data_provider.proto\x12\x10tensorboard.data\x1a\x1fgoogle/protobuf/timestamp.proto\x1a&tensorboard/compat/proto/summary.proto\x1a%tensorboard/compat/proto/tensor.proto\"-\n\x14GetExperimentRequest\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\"\x84\x01\n\x15GetExperimentResponse\x12\x15\n\rdata_location\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x31\n\rcreation_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"#\n\x0cPluginFilter\x12\x13\n\x0bplugin_name\x18\x01 \x01(\t\"d\n\x0cRunTagFilter\x12)\n\x04runs\x18\x01 \x01(\x0b\x32\x1b.tensorboard.data.RunFilter\x12)\n\x04tags\x18\x02 \x01(\x0b\x32\x1b.tensorboard.data.TagFilter\"\x1a\n\tRunFilter\x12\r\n\x05names\x18\x01 \x03(\t\"\x1a\n\tTagFilter\x12\r\n\x05names\x18\x01 \x03(\t\" \n\nDownsample\x12\x12\n\nnum_points\x18\x01 \x01(\x03\"+\n\x12ListPluginsRequest\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\"@\n\x13ListPluginsResponse\x12)\n\x07plugins\x18\x01 \x03(\x0b\x32\x18.tensorboard.data.Plugin\"\x16\n\x06Plugin\x12\x0c\n\x04name\x18\x01 \x01(\t\"(\n\x0fListRunsRequest\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\"7\n\x10ListRunsResponse\x12#\n\x04runs\x18\x01 \x03(\x0b\x32\x15.tensorboard.data.Run\"1\n\x03Run\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nstart_time\x18\x03 \x01(\x01J\x04\x08\x01\x10\x02R\x02id\"\x9a\x01\n\x12ListScalarsRequest\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12\x35\n\rplugin_filter\x18\x02 \x01(\x0b\x32\x1e.tensorboard.data.PluginFilter\x12\x36\n\x0erun_tag_filter\x18\x03 \x01(\x0b\x32\x1e.tensorboard.data.RunTagFilter\"\x81\x02\n\x13ListScalarsResponse\x12<\n\x04runs\x18\x01 \x03(\x0b\x32..tensorboard.data.ListScalarsResponse.RunEntry\x1aZ\n\x08RunEntry\x12\x10\n\x08run_name\x18\x01 \x01(\t\x12<\n\x04tags\x18\x02 \x03(\x0b\x32..tensorboard.data.ListScalarsResponse.TagEntry\x1aP\n\x08TagEntry\x12\x10\n\x08tag_name\x18\x01 \x01(\t\x12\x32\n\x08metadata\x18\x02 \x01(\x0b\x32 .tensorboard.data.ScalarMetadata\"q\n\x0eScalarMetadata\x12\x10\n\x08max_step\x18\x01 \x01(\x03\x12\x15\n\rmax_wall_time\x18\x02 \x01(\x01\x12\x36\n\x10summary_metadata\x18\x03 \x01(\x0b\x32\x1c.tensorboard.SummaryMetadata\"\xcc\x01\n\x12ReadScalarsRequest\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12\x35\n\rplugin_filter\x18\x02 \x01(\x0b\x32\x1e.tensorboard.data.PluginFilter\x12\x36\n\x0erun_tag_filter\x18\x03 \x01(\x0b\x32\x1e.tensorboard.data.RunTagFilter\x12\x30\n\ndownsample\x18\x04 \x01(\x0b\x32\x1c.tensorboard.data.Downsample\"\xf9\x01\n\x13ReadScalarsResponse\x12<\n\x04runs\x18\x01 \x03(\x0b\x32..tensorboard.data.ReadScalarsResponse.RunEntry\x1aZ\n\x08RunEntry\x12\x10\n\x08run_name\x18\x01 \x01(\t\x12<\n\x04tags\x18\x02 \x03(\x0b\x32..tensorboard.data.ReadScalarsResponse.TagEntry\x1aH\n\x08TagEntry\x12\x10\n\x08tag_name\x18\x01 \x01(\t\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.tensorboard.data.ScalarData\"<\n\nScalarData\x12\x0c\n\x04step\x18\x01 \x03(\x03\x12\x11\n\twall_time\x18\x02 \x03(\x01\x12\r\n\x05value\x18\x03 \x03(\x02\"\x9a\x01\n\x12ListTensorsRequest\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12\x35\n\rplugin_filter\x18\x02 \x01(\x0b\x32\x1e.tensorboard.data.PluginFilter\x12\x36\n\x0erun_tag_filter\x18\x03 \x01(\x0b\x32\x1e.tensorboard.data.RunTagFilter\"\x81\x02\n\x13ListTensorsResponse\x12<\n\x04runs\x18\x01 \x03(\x0b\x32..tensorboard.data.ListTensorsResponse.RunEntry\x1aZ\n\x08RunEntry\x12\x10\n\x08run_name\x18\x01 \x01(\t\x12<\n\x04tags\x18\x02 \x03(\x0b\x32..tensorboard.data.ListTensorsResponse.TagEntry\x1aP\n\x08TagEntry\x12\x10\n\x08tag_name\x18\x01 \x01(\t\x12\x32\n\x08metadata\x18\x02 \x01(\x0b\x32 .tensorboard.data.TensorMetadata\"q\n\x0eTensorMetadata\x12\x10\n\x08max_step\x18\x01 \x01(\x03\x12\x15\n\rmax_wall_time\x18\x02 \x01(\x01\x12\x36\n\x10summary_metadata\x18\x03 \x01(\x0b\x32\x1c.tensorboard.SummaryMetadata\"\xcc\x01\n\x12ReadTensorsRequest\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12\x35\n\rplugin_filter\x18\x02 \x01(\x0b\x32\x1e.tensorboard.data.PluginFilter\x12\x36\n\x0erun_tag_filter\x18\x03 \x01(\x0b\x32\x1e.tensorboard.data.RunTagFilter\x12\x30\n\ndownsample\x18\x04 \x01(\x0b\x32\x1c.tensorboard.data.Downsample\"\xf9\x01\n\x13ReadTensorsResponse\x12<\n\x04runs\x18\x01 \x03(\x0b\x32..tensorboard.data.ReadTensorsResponse.RunEntry\x1aZ\n\x08RunEntry\x12\x10\n\x08run_name\x18\x01 \x01(\t\x12<\n\x04tags\x18\x02 \x03(\x0b\x32..tensorboard.data.ReadTensorsResponse.TagEntry\x1aH\n\x08TagEntry\x12\x10\n\x08tag_name\x18\x01 \x01(\t\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.tensorboard.data.TensorData\"V\n\nTensorData\x12\x0c\n\x04step\x18\x01 \x03(\x03\x12\x11\n\twall_time\x18\x02 \x03(\x01\x12\'\n\x05value\x18\x03 \x03(\x0b\x32\x18.tensorboard.TensorProto\"\xa0\x01\n\x18ListBlobSequencesRequest\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12\x35\n\rplugin_filter\x18\x02 \x01(\x0b\x32\x1e.tensorboard.data.PluginFilter\x12\x36\n\x0erun_tag_filter\x18\x03 \x01(\x0b\x32\x1e.tensorboard.data.RunTagFilter\"\x99\x02\n\x19ListBlobSequencesResponse\x12\x42\n\x04runs\x18\x01 \x03(\x0b\x32\x34.tensorboard.data.ListBlobSequencesResponse.RunEntry\x1a`\n\x08RunEntry\x12\x10\n\x08run_name\x18\x01 \x01(\t\x12\x42\n\x04tags\x18\x02 \x03(\x0b\x32\x34.tensorboard.data.ListBlobSequencesResponse.TagEntry\x1aV\n\x08TagEntry\x12\x10\n\x08tag_name\x18\x01 \x01(\t\x12\x38\n\x08metadata\x18\x02 \x01(\x0b\x32&.tensorboard.data.BlobSequenceMetadata\"\x8b\x01\n\x14\x42lobSequenceMetadata\x12\x10\n\x08max_step\x18\x01 \x01(\x03\x12\x15\n\rmax_wall_time\x18\x02 \x01(\x01\x12\x12\n\nmax_length\x18\x03 \x01(\x03\x12\x36\n\x10summary_metadata\x18\x04 \x01(\x0b\x32\x1c.tensorboard.SummaryMetadata\"\xd2\x01\n\x18ReadBlobSequencesRequest\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12\x35\n\rplugin_filter\x18\x02 \x01(\x0b\x32\x1e.tensorboard.data.PluginFilter\x12\x36\n\x0erun_tag_filter\x18\x03 \x01(\x0b\x32\x1e.tensorboard.data.RunTagFilter\x12\x30\n\ndownsample\x18\x04 \x01(\x0b\x32\x1c.tensorboard.data.Downsample\"\x91\x02\n\x19ReadBlobSequencesResponse\x12\x42\n\x04runs\x18\x01 \x03(\x0b\x32\x34.tensorboard.data.ReadBlobSequencesResponse.RunEntry\x1a`\n\x08RunEntry\x12\x10\n\x08run_name\x18\x01 \x01(\t\x12\x42\n\x04tags\x18\x02 \x03(\x0b\x32\x34.tensorboard.data.ReadBlobSequencesResponse.TagEntry\x1aN\n\x08TagEntry\x12\x10\n\x08tag_name\x18\x01 \x01(\t\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".tensorboard.data.BlobSequenceData\"l\n\x10\x42lobSequenceData\x12\x0c\n\x04step\x18\x01 \x03(\x03\x12\x11\n\twall_time\x18\x02 \x03(\x01\x12\x37\n\x06values\x18\x03 \x03(\x0b\x32\'.tensorboard.data.BlobReferenceSequence\"K\n\x15\x42lobReferenceSequence\x12\x32\n\tblob_refs\x18\x01 \x03(\x0b\x32\x1f.tensorboard.data.BlobReference\".\n\rBlobReference\x12\x10\n\x08\x62lob_key\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"#\n\x0fReadBlobRequest\x12\x10\n\x08\x62lob_key\x18\x01 \x01(\t\" \n\x10ReadBlobResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x32\xdd\x07\n\x17TensorBoardDataProvider\x12`\n\rGetExperiment\x12&.tensorboard.data.GetExperimentRequest\x1a\'.tensorboard.data.GetExperimentResponse\x12\\\n\x0bListPlugins\x12$.tensorboard.data.ListPluginsRequest\x1a%.tensorboard.data.ListPluginsResponse\"\x00\x12S\n\x08ListRuns\x12!.tensorboard.data.ListRunsRequest\x1a\".tensorboard.data.ListRunsResponse\"\x00\x12\\\n\x0bListScalars\x12$.tensorboard.data.ListScalarsRequest\x1a%.tensorboard.data.ListScalarsResponse\"\x00\x12\\\n\x0bReadScalars\x12$.tensorboard.data.ReadScalarsRequest\x1a%.tensorboard.data.ReadScalarsResponse\"\x00\x12\\\n\x0bListTensors\x12$.tensorboard.data.ListTensorsRequest\x1a%.tensorboard.data.ListTensorsResponse\"\x00\x12\\\n\x0bReadTensors\x12$.tensorboard.data.ReadTensorsRequest\x1a%.tensorboard.data.ReadTensorsResponse\"\x00\x12n\n\x11ListBlobSequences\x12*.tensorboard.data.ListBlobSequencesRequest\x1a+.tensorboard.data.ListBlobSequencesResponse\"\x00\x12n\n\x11ReadBlobSequences\x12*.tensorboard.data.ReadBlobSequencesRequest\x1a+.tensorboard.data.ReadBlobSequencesResponse\"\x00\x12U\n\x08ReadBlob\x12!.tensorboard.data.ReadBlobRequest\x1a\".tensorboard.data.ReadBlobResponse\"\x00\x30\x01\x42NZLgithub.com/tensorflow/tensorboard/tensorboard/data/proto/data_provider_protob\x06proto3')



_GETEXPERIMENTREQUEST = DESCRIPTOR.message_types_by_name['GetExperimentRequest']
_GETEXPERIMENTRESPONSE = DESCRIPTOR.message_types_by_name['GetExperimentResponse']
_PLUGINFILTER = DESCRIPTOR.message_types_by_name['PluginFilter']
_RUNTAGFILTER = DESCRIPTOR.message_types_by_name['RunTagFilter']
_RUNFILTER = DESCRIPTOR.message_types_by_name['RunFilter']
_TAGFILTER = DESCRIPTOR.message_types_by_name['TagFilter']
_DOWNSAMPLE = DESCRIPTOR.message_types_by_name['Downsample']
_LISTPLUGINSREQUEST = DESCRIPTOR.message_types_by_name['ListPluginsRequest']
_LISTPLUGINSRESPONSE = DESCRIPTOR.message_types_by_name['ListPluginsResponse']
_PLUGIN = DESCRIPTOR.message_types_by_name['Plugin']
_LISTRUNSREQUEST = DESCRIPTOR.message_types_by_name['ListRunsRequest']
_LISTRUNSRESPONSE = DESCRIPTOR.message_types_by_name['ListRunsResponse']
_RUN = DESCRIPTOR.message_types_by_name['Run']
_LISTSCALARSREQUEST = DESCRIPTOR.message_types_by_name['ListScalarsRequest']
_LISTSCALARSRESPONSE = DESCRIPTOR.message_types_by_name['ListScalarsResponse']
_LISTSCALARSRESPONSE_RUNENTRY = _LISTSCALARSRESPONSE.nested_types_by_name['RunEntry']
_LISTSCALARSRESPONSE_TAGENTRY = _LISTSCALARSRESPONSE.nested_types_by_name['TagEntry']
_SCALARMETADATA = DESCRIPTOR.message_types_by_name['ScalarMetadata']
_READSCALARSREQUEST = DESCRIPTOR.message_types_by_name['ReadScalarsRequest']
_READSCALARSRESPONSE = DESCRIPTOR.message_types_by_name['ReadScalarsResponse']
_READSCALARSRESPONSE_RUNENTRY = _READSCALARSRESPONSE.nested_types_by_name['RunEntry']
_READSCALARSRESPONSE_TAGENTRY = _READSCALARSRESPONSE.nested_types_by_name['TagEntry']
_SCALARDATA = DESCRIPTOR.message_types_by_name['ScalarData']
_LISTTENSORSREQUEST = DESCRIPTOR.message_types_by_name['ListTensorsRequest']
_LISTTENSORSRESPONSE = DESCRIPTOR.message_types_by_name['ListTensorsResponse']
_LISTTENSORSRESPONSE_RUNENTRY = _LISTTENSORSRESPONSE.nested_types_by_name['RunEntry']
_LISTTENSORSRESPONSE_TAGENTRY = _LISTTENSORSRESPONSE.nested_types_by_name['TagEntry']
_TENSORMETADATA = DESCRIPTOR.message_types_by_name['TensorMetadata']
_READTENSORSREQUEST = DESCRIPTOR.message_types_by_name['ReadTensorsRequest']
_READTENSORSRESPONSE = DESCRIPTOR.message_types_by_name['ReadTensorsResponse']
_READTENSORSRESPONSE_RUNENTRY = _READTENSORSRESPONSE.nested_types_by_name['RunEntry']
_READTENSORSRESPONSE_TAGENTRY = _READTENSORSRESPONSE.nested_types_by_name['TagEntry']
_TENSORDATA = DESCRIPTOR.message_types_by_name['TensorData']
_LISTBLOBSEQUENCESREQUEST = DESCRIPTOR.message_types_by_name['ListBlobSequencesRequest']
_LISTBLOBSEQUENCESRESPONSE = DESCRIPTOR.message_types_by_name['ListBlobSequencesResponse']
_LISTBLOBSEQUENCESRESPONSE_RUNENTRY = _LISTBLOBSEQUENCESRESPONSE.nested_types_by_name['RunEntry']
_LISTBLOBSEQUENCESRESPONSE_TAGENTRY = _LISTBLOBSEQUENCESRESPONSE.nested_types_by_name['TagEntry']
_BLOBSEQUENCEMETADATA = DESCRIPTOR.message_types_by_name['BlobSequenceMetadata']
_READBLOBSEQUENCESREQUEST = DESCRIPTOR.message_types_by_name['ReadBlobSequencesRequest']
_READBLOBSEQUENCESRESPONSE = DESCRIPTOR.message_types_by_name['ReadBlobSequencesResponse']
_READBLOBSEQUENCESRESPONSE_RUNENTRY = _READBLOBSEQUENCESRESPONSE.nested_types_by_name['RunEntry']
_READBLOBSEQUENCESRESPONSE_TAGENTRY = _READBLOBSEQUENCESRESPONSE.nested_types_by_name['TagEntry']
_BLOBSEQUENCEDATA = DESCRIPTOR.message_types_by_name['BlobSequenceData']
_BLOBREFERENCESEQUENCE = DESCRIPTOR.message_types_by_name['BlobReferenceSequence']
_BLOBREFERENCE = DESCRIPTOR.message_types_by_name['BlobReference']
_READBLOBREQUEST = DESCRIPTOR.message_types_by_name['ReadBlobRequest']
_READBLOBRESPONSE = DESCRIPTOR.message_types_by_name['ReadBlobResponse']
GetExperimentRequest = _reflection.GeneratedProtocolMessageType('GetExperimentRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETEXPERIMENTREQUEST,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.GetExperimentRequest)
  })
_sym_db.RegisterMessage(GetExperimentRequest)

GetExperimentResponse = _reflection.GeneratedProtocolMessageType('GetExperimentResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETEXPERIMENTRESPONSE,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.GetExperimentResponse)
  })
_sym_db.RegisterMessage(GetExperimentResponse)

PluginFilter = _reflection.GeneratedProtocolMessageType('PluginFilter', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINFILTER,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.PluginFilter)
  })
_sym_db.RegisterMessage(PluginFilter)

RunTagFilter = _reflection.GeneratedProtocolMessageType('RunTagFilter', (_message.Message,), {
  'DESCRIPTOR' : _RUNTAGFILTER,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.RunTagFilter)
  })
_sym_db.RegisterMessage(RunTagFilter)

RunFilter = _reflection.GeneratedProtocolMessageType('RunFilter', (_message.Message,), {
  'DESCRIPTOR' : _RUNFILTER,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.RunFilter)
  })
_sym_db.RegisterMessage(RunFilter)

TagFilter = _reflection.GeneratedProtocolMessageType('TagFilter', (_message.Message,), {
  'DESCRIPTOR' : _TAGFILTER,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.TagFilter)
  })
_sym_db.RegisterMessage(TagFilter)

Downsample = _reflection.GeneratedProtocolMessageType('Downsample', (_message.Message,), {
  'DESCRIPTOR' : _DOWNSAMPLE,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.Downsample)
  })
_sym_db.RegisterMessage(Downsample)

ListPluginsRequest = _reflection.GeneratedProtocolMessageType('ListPluginsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPLUGINSREQUEST,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.ListPluginsRequest)
  })
_sym_db.RegisterMessage(ListPluginsRequest)

ListPluginsResponse = _reflection.GeneratedProtocolMessageType('ListPluginsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPLUGINSRESPONSE,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.ListPluginsResponse)
  })
_sym_db.RegisterMessage(ListPluginsResponse)

Plugin = _reflection.GeneratedProtocolMessageType('Plugin', (_message.Message,), {
  'DESCRIPTOR' : _PLUGIN,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.Plugin)
  })
_sym_db.RegisterMessage(Plugin)

ListRunsRequest = _reflection.GeneratedProtocolMessageType('ListRunsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTRUNSREQUEST,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.ListRunsRequest)
  })
_sym_db.RegisterMessage(ListRunsRequest)

ListRunsResponse = _reflection.GeneratedProtocolMessageType('ListRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRUNSRESPONSE,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.ListRunsResponse)
  })
_sym_db.RegisterMessage(ListRunsResponse)

Run = _reflection.GeneratedProtocolMessageType('Run', (_message.Message,), {
  'DESCRIPTOR' : _RUN,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.Run)
  })
_sym_db.RegisterMessage(Run)

ListScalarsRequest = _reflection.GeneratedProtocolMessageType('ListScalarsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSCALARSREQUEST,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.ListScalarsRequest)
  })
_sym_db.RegisterMessage(ListScalarsRequest)

ListScalarsResponse = _reflection.GeneratedProtocolMessageType('ListScalarsResponse', (_message.Message,), {

  'RunEntry' : _reflection.GeneratedProtocolMessageType('RunEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTSCALARSRESPONSE_RUNENTRY,
    '__module__' : 'tensorboard.data.proto.data_provider_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.data.ListScalarsResponse.RunEntry)
    })
  ,

  'TagEntry' : _reflection.GeneratedProtocolMessageType('TagEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTSCALARSRESPONSE_TAGENTRY,
    '__module__' : 'tensorboard.data.proto.data_provider_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.data.ListScalarsResponse.TagEntry)
    })
  ,
  'DESCRIPTOR' : _LISTSCALARSRESPONSE,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.ListScalarsResponse)
  })
_sym_db.RegisterMessage(ListScalarsResponse)
_sym_db.RegisterMessage(ListScalarsResponse.RunEntry)
_sym_db.RegisterMessage(ListScalarsResponse.TagEntry)

ScalarMetadata = _reflection.GeneratedProtocolMessageType('ScalarMetadata', (_message.Message,), {
  'DESCRIPTOR' : _SCALARMETADATA,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.ScalarMetadata)
  })
_sym_db.RegisterMessage(ScalarMetadata)

ReadScalarsRequest = _reflection.GeneratedProtocolMessageType('ReadScalarsRequest', (_message.Message,), {
  'DESCRIPTOR' : _READSCALARSREQUEST,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.ReadScalarsRequest)
  })
_sym_db.RegisterMessage(ReadScalarsRequest)

ReadScalarsResponse = _reflection.GeneratedProtocolMessageType('ReadScalarsResponse', (_message.Message,), {

  'RunEntry' : _reflection.GeneratedProtocolMessageType('RunEntry', (_message.Message,), {
    'DESCRIPTOR' : _READSCALARSRESPONSE_RUNENTRY,
    '__module__' : 'tensorboard.data.proto.data_provider_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.data.ReadScalarsResponse.RunEntry)
    })
  ,

  'TagEntry' : _reflection.GeneratedProtocolMessageType('TagEntry', (_message.Message,), {
    'DESCRIPTOR' : _READSCALARSRESPONSE_TAGENTRY,
    '__module__' : 'tensorboard.data.proto.data_provider_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.data.ReadScalarsResponse.TagEntry)
    })
  ,
  'DESCRIPTOR' : _READSCALARSRESPONSE,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.ReadScalarsResponse)
  })
_sym_db.RegisterMessage(ReadScalarsResponse)
_sym_db.RegisterMessage(ReadScalarsResponse.RunEntry)
_sym_db.RegisterMessage(ReadScalarsResponse.TagEntry)

ScalarData = _reflection.GeneratedProtocolMessageType('ScalarData', (_message.Message,), {
  'DESCRIPTOR' : _SCALARDATA,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.ScalarData)
  })
_sym_db.RegisterMessage(ScalarData)

ListTensorsRequest = _reflection.GeneratedProtocolMessageType('ListTensorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTENSORSREQUEST,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.ListTensorsRequest)
  })
_sym_db.RegisterMessage(ListTensorsRequest)

ListTensorsResponse = _reflection.GeneratedProtocolMessageType('ListTensorsResponse', (_message.Message,), {

  'RunEntry' : _reflection.GeneratedProtocolMessageType('RunEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTTENSORSRESPONSE_RUNENTRY,
    '__module__' : 'tensorboard.data.proto.data_provider_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.data.ListTensorsResponse.RunEntry)
    })
  ,

  'TagEntry' : _reflection.GeneratedProtocolMessageType('TagEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTTENSORSRESPONSE_TAGENTRY,
    '__module__' : 'tensorboard.data.proto.data_provider_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.data.ListTensorsResponse.TagEntry)
    })
  ,
  'DESCRIPTOR' : _LISTTENSORSRESPONSE,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.ListTensorsResponse)
  })
_sym_db.RegisterMessage(ListTensorsResponse)
_sym_db.RegisterMessage(ListTensorsResponse.RunEntry)
_sym_db.RegisterMessage(ListTensorsResponse.TagEntry)

TensorMetadata = _reflection.GeneratedProtocolMessageType('TensorMetadata', (_message.Message,), {
  'DESCRIPTOR' : _TENSORMETADATA,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.TensorMetadata)
  })
_sym_db.RegisterMessage(TensorMetadata)

ReadTensorsRequest = _reflection.GeneratedProtocolMessageType('ReadTensorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _READTENSORSREQUEST,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.ReadTensorsRequest)
  })
_sym_db.RegisterMessage(ReadTensorsRequest)

ReadTensorsResponse = _reflection.GeneratedProtocolMessageType('ReadTensorsResponse', (_message.Message,), {

  'RunEntry' : _reflection.GeneratedProtocolMessageType('RunEntry', (_message.Message,), {
    'DESCRIPTOR' : _READTENSORSRESPONSE_RUNENTRY,
    '__module__' : 'tensorboard.data.proto.data_provider_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.data.ReadTensorsResponse.RunEntry)
    })
  ,

  'TagEntry' : _reflection.GeneratedProtocolMessageType('TagEntry', (_message.Message,), {
    'DESCRIPTOR' : _READTENSORSRESPONSE_TAGENTRY,
    '__module__' : 'tensorboard.data.proto.data_provider_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.data.ReadTensorsResponse.TagEntry)
    })
  ,
  'DESCRIPTOR' : _READTENSORSRESPONSE,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.ReadTensorsResponse)
  })
_sym_db.RegisterMessage(ReadTensorsResponse)
_sym_db.RegisterMessage(ReadTensorsResponse.RunEntry)
_sym_db.RegisterMessage(ReadTensorsResponse.TagEntry)

TensorData = _reflection.GeneratedProtocolMessageType('TensorData', (_message.Message,), {
  'DESCRIPTOR' : _TENSORDATA,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.TensorData)
  })
_sym_db.RegisterMessage(TensorData)

ListBlobSequencesRequest = _reflection.GeneratedProtocolMessageType('ListBlobSequencesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBLOBSEQUENCESREQUEST,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.ListBlobSequencesRequest)
  })
_sym_db.RegisterMessage(ListBlobSequencesRequest)

ListBlobSequencesResponse = _reflection.GeneratedProtocolMessageType('ListBlobSequencesResponse', (_message.Message,), {

  'RunEntry' : _reflection.GeneratedProtocolMessageType('RunEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTBLOBSEQUENCESRESPONSE_RUNENTRY,
    '__module__' : 'tensorboard.data.proto.data_provider_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.data.ListBlobSequencesResponse.RunEntry)
    })
  ,

  'TagEntry' : _reflection.GeneratedProtocolMessageType('TagEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTBLOBSEQUENCESRESPONSE_TAGENTRY,
    '__module__' : 'tensorboard.data.proto.data_provider_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.data.ListBlobSequencesResponse.TagEntry)
    })
  ,
  'DESCRIPTOR' : _LISTBLOBSEQUENCESRESPONSE,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.ListBlobSequencesResponse)
  })
_sym_db.RegisterMessage(ListBlobSequencesResponse)
_sym_db.RegisterMessage(ListBlobSequencesResponse.RunEntry)
_sym_db.RegisterMessage(ListBlobSequencesResponse.TagEntry)

BlobSequenceMetadata = _reflection.GeneratedProtocolMessageType('BlobSequenceMetadata', (_message.Message,), {
  'DESCRIPTOR' : _BLOBSEQUENCEMETADATA,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.BlobSequenceMetadata)
  })
_sym_db.RegisterMessage(BlobSequenceMetadata)

ReadBlobSequencesRequest = _reflection.GeneratedProtocolMessageType('ReadBlobSequencesRequest', (_message.Message,), {
  'DESCRIPTOR' : _READBLOBSEQUENCESREQUEST,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.ReadBlobSequencesRequest)
  })
_sym_db.RegisterMessage(ReadBlobSequencesRequest)

ReadBlobSequencesResponse = _reflection.GeneratedProtocolMessageType('ReadBlobSequencesResponse', (_message.Message,), {

  'RunEntry' : _reflection.GeneratedProtocolMessageType('RunEntry', (_message.Message,), {
    'DESCRIPTOR' : _READBLOBSEQUENCESRESPONSE_RUNENTRY,
    '__module__' : 'tensorboard.data.proto.data_provider_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.data.ReadBlobSequencesResponse.RunEntry)
    })
  ,

  'TagEntry' : _reflection.GeneratedProtocolMessageType('TagEntry', (_message.Message,), {
    'DESCRIPTOR' : _READBLOBSEQUENCESRESPONSE_TAGENTRY,
    '__module__' : 'tensorboard.data.proto.data_provider_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.data.ReadBlobSequencesResponse.TagEntry)
    })
  ,
  'DESCRIPTOR' : _READBLOBSEQUENCESRESPONSE,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.ReadBlobSequencesResponse)
  })
_sym_db.RegisterMessage(ReadBlobSequencesResponse)
_sym_db.RegisterMessage(ReadBlobSequencesResponse.RunEntry)
_sym_db.RegisterMessage(ReadBlobSequencesResponse.TagEntry)

BlobSequenceData = _reflection.GeneratedProtocolMessageType('BlobSequenceData', (_message.Message,), {
  'DESCRIPTOR' : _BLOBSEQUENCEDATA,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.BlobSequenceData)
  })
_sym_db.RegisterMessage(BlobSequenceData)

BlobReferenceSequence = _reflection.GeneratedProtocolMessageType('BlobReferenceSequence', (_message.Message,), {
  'DESCRIPTOR' : _BLOBREFERENCESEQUENCE,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.BlobReferenceSequence)
  })
_sym_db.RegisterMessage(BlobReferenceSequence)

BlobReference = _reflection.GeneratedProtocolMessageType('BlobReference', (_message.Message,), {
  'DESCRIPTOR' : _BLOBREFERENCE,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.BlobReference)
  })
_sym_db.RegisterMessage(BlobReference)

ReadBlobRequest = _reflection.GeneratedProtocolMessageType('ReadBlobRequest', (_message.Message,), {
  'DESCRIPTOR' : _READBLOBREQUEST,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.ReadBlobRequest)
  })
_sym_db.RegisterMessage(ReadBlobRequest)

ReadBlobResponse = _reflection.GeneratedProtocolMessageType('ReadBlobResponse', (_message.Message,), {
  'DESCRIPTOR' : _READBLOBRESPONSE,
  '__module__' : 'tensorboard.data.proto.data_provider_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.data.ReadBlobResponse)
  })
_sym_db.RegisterMessage(ReadBlobResponse)

_TENSORBOARDDATAPROVIDER = DESCRIPTOR.services_by_name['TensorBoardDataProvider']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZLgithub.com/tensorflow/tensorboard/tensorboard/data/proto/data_provider_proto'
  _GETEXPERIMENTREQUEST._serialized_start=176
  _GETEXPERIMENTREQUEST._serialized_end=221
  _GETEXPERIMENTRESPONSE._serialized_start=224
  _GETEXPERIMENTRESPONSE._serialized_end=356
  _PLUGINFILTER._serialized_start=358
  _PLUGINFILTER._serialized_end=393
  _RUNTAGFILTER._serialized_start=395
  _RUNTAGFILTER._serialized_end=495
  _RUNFILTER._serialized_start=497
  _RUNFILTER._serialized_end=523
  _TAGFILTER._serialized_start=525
  _TAGFILTER._serialized_end=551
  _DOWNSAMPLE._serialized_start=553
  _DOWNSAMPLE._serialized_end=585
  _LISTPLUGINSREQUEST._serialized_start=587
  _LISTPLUGINSREQUEST._serialized_end=630
  _LISTPLUGINSRESPONSE._serialized_start=632
  _LISTPLUGINSRESPONSE._serialized_end=696
  _PLUGIN._serialized_start=698
  _PLUGIN._serialized_end=720
  _LISTRUNSREQUEST._serialized_start=722
  _LISTRUNSREQUEST._serialized_end=762
  _LISTRUNSRESPONSE._serialized_start=764
  _LISTRUNSRESPONSE._serialized_end=819
  _RUN._serialized_start=821
  _RUN._serialized_end=870
  _LISTSCALARSREQUEST._serialized_start=873
  _LISTSCALARSREQUEST._serialized_end=1027
  _LISTSCALARSRESPONSE._serialized_start=1030
  _LISTSCALARSRESPONSE._serialized_end=1287
  _LISTSCALARSRESPONSE_RUNENTRY._serialized_start=1115
  _LISTSCALARSRESPONSE_RUNENTRY._serialized_end=1205
  _LISTSCALARSRESPONSE_TAGENTRY._serialized_start=1207
  _LISTSCALARSRESPONSE_TAGENTRY._serialized_end=1287
  _SCALARMETADATA._serialized_start=1289
  _SCALARMETADATA._serialized_end=1402
  _READSCALARSREQUEST._serialized_start=1405
  _READSCALARSREQUEST._serialized_end=1609
  _READSCALARSRESPONSE._serialized_start=1612
  _READSCALARSRESPONSE._serialized_end=1861
  _READSCALARSRESPONSE_RUNENTRY._serialized_start=1697
  _READSCALARSRESPONSE_RUNENTRY._serialized_end=1787
  _READSCALARSRESPONSE_TAGENTRY._serialized_start=1789
  _READSCALARSRESPONSE_TAGENTRY._serialized_end=1861
  _SCALARDATA._serialized_start=1863
  _SCALARDATA._serialized_end=1923
  _LISTTENSORSREQUEST._serialized_start=1926
  _LISTTENSORSREQUEST._serialized_end=2080
  _LISTTENSORSRESPONSE._serialized_start=2083
  _LISTTENSORSRESPONSE._serialized_end=2340
  _LISTTENSORSRESPONSE_RUNENTRY._serialized_start=2168
  _LISTTENSORSRESPONSE_RUNENTRY._serialized_end=2258
  _LISTTENSORSRESPONSE_TAGENTRY._serialized_start=2260
  _LISTTENSORSRESPONSE_TAGENTRY._serialized_end=2340
  _TENSORMETADATA._serialized_start=2342
  _TENSORMETADATA._serialized_end=2455
  _READTENSORSREQUEST._serialized_start=2458
  _READTENSORSREQUEST._serialized_end=2662
  _READTENSORSRESPONSE._serialized_start=2665
  _READTENSORSRESPONSE._serialized_end=2914
  _READTENSORSRESPONSE_RUNENTRY._serialized_start=2750
  _READTENSORSRESPONSE_RUNENTRY._serialized_end=2840
  _READTENSORSRESPONSE_TAGENTRY._serialized_start=2842
  _READTENSORSRESPONSE_TAGENTRY._serialized_end=2914
  _TENSORDATA._serialized_start=2916
  _TENSORDATA._serialized_end=3002
  _LISTBLOBSEQUENCESREQUEST._serialized_start=3005
  _LISTBLOBSEQUENCESREQUEST._serialized_end=3165
  _LISTBLOBSEQUENCESRESPONSE._serialized_start=3168
  _LISTBLOBSEQUENCESRESPONSE._serialized_end=3449
  _LISTBLOBSEQUENCESRESPONSE_RUNENTRY._serialized_start=3265
  _LISTBLOBSEQUENCESRESPONSE_RUNENTRY._serialized_end=3361
  _LISTBLOBSEQUENCESRESPONSE_TAGENTRY._serialized_start=3363
  _LISTBLOBSEQUENCESRESPONSE_TAGENTRY._serialized_end=3449
  _BLOBSEQUENCEMETADATA._serialized_start=3452
  _BLOBSEQUENCEMETADATA._serialized_end=3591
  _READBLOBSEQUENCESREQUEST._serialized_start=3594
  _READBLOBSEQUENCESREQUEST._serialized_end=3804
  _READBLOBSEQUENCESRESPONSE._serialized_start=3807
  _READBLOBSEQUENCESRESPONSE._serialized_end=4080
  _READBLOBSEQUENCESRESPONSE_RUNENTRY._serialized_start=3904
  _READBLOBSEQUENCESRESPONSE_RUNENTRY._serialized_end=4000
  _READBLOBSEQUENCESRESPONSE_TAGENTRY._serialized_start=4002
  _READBLOBSEQUENCESRESPONSE_TAGENTRY._serialized_end=4080
  _BLOBSEQUENCEDATA._serialized_start=4082
  _BLOBSEQUENCEDATA._serialized_end=4190
  _BLOBREFERENCESEQUENCE._serialized_start=4192
  _BLOBREFERENCESEQUENCE._serialized_end=4267
  _BLOBREFERENCE._serialized_start=4269
  _BLOBREFERENCE._serialized_end=4315
  _READBLOBREQUEST._serialized_start=4317
  _READBLOBREQUEST._serialized_end=4352
  _READBLOBRESPONSE._serialized_start=4354
  _READBLOBRESPONSE._serialized_end=4386
  _TENSORBOARDDATAPROVIDER._serialized_start=4389
  _TENSORBOARDDATAPROVIDER._serialized_end=5378
# @@protoc_insertion_point(module_scope)



# Copyright 2019 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
"""Internal information about the mesh plugin."""

import dataclasses

from typing import Any

from tensorboard.compat.proto import summary_pb2
from tensorboard.plugins.mesh import plugin_data_pb2

PLUGIN_NAME = "mesh"

# The most recent value for the `version` field of the
# `MeshPluginData` proto.
_PROTO_VERSION = 0


@dataclasses.dataclass(frozen=True)
class MeshTensor:
    """A mesh tensor.

    Attributes:
      data: Tensor of shape `[dim_1, ..., dim_n, 3]` representing the mesh data
        of one of the following:
          - 3D coordinates of vertices
          - Indices of vertices within each triangle
          - Colors for each vertex
      content_type: Type of the mesh plugin data content.
      data_type: Data type of the elements in the tensor.
    """

    data: Any  # Expects type `tf.Tensor`, not specified here to avoid heavy TF dep.
    content_type: plugin_data_pb2.MeshPluginData.ContentType
    data_type: Any  # Expects type `tf.DType`, not specified here to avoid heavy TF dep.


def get_components_bitmask(content_types):
    """Creates bitmask for all existing components of the summary.

    Args:
      content_type: list of plugin_data_pb2.MeshPluginData.ContentType,
        representing all components related to the summary.
    Returns: bitmask based on passed tensors.
    """
    components = 0
    for content_type in content_types:
        if content_type == plugin_data_pb2.MeshPluginData.UNDEFINED:
            raise ValueError("Cannot include UNDEFINED content type in mask.")
        components = components | (1 << content_type)
    return components


def get_current_version():
    """Returns current verions of the proto."""
    return _PROTO_VERSION


def get_instance_name(name, content_type):
    """Returns a unique instance name for a given summary related to the
    mesh."""
    return "%s_%s" % (
        name,
        plugin_data_pb2.MeshPluginData.ContentType.Name(content_type),
    )


def create_summary_metadata(
    name,
    display_name,
    content_type,
    components,
    shape,
    description=None,
    json_config=None,
):
    """Creates summary metadata which defined at MeshPluginData proto.

    Arguments:
      name: Original merged (summaries of different types) summary name.
      display_name: The display name used in TensorBoard.
      content_type: Value from MeshPluginData.ContentType enum describing data.
      components: Bitmask representing present parts (vertices, colors, etc.) that
        belong to the summary.
      shape: list of dimensions sizes of the tensor.
      description: The description to show in TensorBoard.
      json_config: A string, JSON-serialized dictionary of ThreeJS classes
        configuration.

    Returns:
      A `summary_pb2.SummaryMetadata` protobuf object.
    """
    # Shape should be at least BxNx3 where B represents the batch dimensions
    # and N - the number of points, each with x,y,z coordinates.
    if len(shape) != 3:
        raise ValueError(
            "Tensor shape should be of shape BxNx3, but got %s." % str(shape)
        )
    mesh_plugin_data = plugin_data_pb2.MeshPluginData(
        version=get_current_version(),
        name=name,
        content_type=content_type,
        components=components,
        shape=shape,
        json_config=json_config,
    )
    content = mesh_plugin_data.SerializeToString()
    return summary_pb2.SummaryMetadata(
        display_name=display_name,  # Will not be used in TensorBoard UI.
        summary_description=description,
        plugin_data=summary_pb2.SummaryMetadata.PluginData(
            plugin_name=PLUGIN_NAME, content=content
        ),
    )


def parse_plugin_metadata(content):
    """Parse summary metadata to a Python object.

    Arguments:
      content: The `content` field of a `SummaryMetadata` proto
        corresponding to the mesh plugin.

    Returns:
      A `MeshPluginData` protobuf object.
    Raises: Error if the version of the plugin is not supported.
    """
    if not isinstance(content, bytes):
        raise TypeError("Content type must be bytes.")
    result = plugin_data_pb2.MeshPluginData.FromString(content)
    # Add components field to older version of the proto.
    if result.components == 0:
        result.components = get_components_bitmask(
            [
                plugin_data_pb2.MeshPluginData.VERTEX,
                plugin_data_pb2.MeshPluginData.FACE,
                plugin_data_pb2.MeshPluginData.COLOR,
            ]
        )
    return result



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorboard/compat/proto/graph.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tensorboard.compat.proto import function_pb2 as tensorboard_dot_compat_dot_proto_dot_function__pb2
from tensorboard.compat.proto import node_def_pb2 as tensorboard_dot_compat_dot_proto_dot_node__def__pb2
from tensorboard.compat.proto import versions_pb2 as tensorboard_dot_compat_dot_proto_dot_versions__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$tensorboard/compat/proto/graph.proto\x12\x0btensorboard\x1a\'tensorboard/compat/proto/function.proto\x1a\'tensorboard/compat/proto/node_def.proto\x1a\'tensorboard/compat/proto/versions.proto\"\xa0\x01\n\x08GraphDef\x12\"\n\x04node\x18\x01 \x03(\x0b\x32\x14.tensorboard.NodeDef\x12)\n\x08versions\x18\x04 \x01(\x0b\x32\x17.tensorboard.VersionDef\x12\x13\n\x07version\x18\x03 \x01(\x05\x42\x02\x18\x01\x12\x30\n\x07library\x18\x02 \x01(\x0b\x32\x1f.tensorboard.FunctionDefLibraryBz\n\x18org.tensorflow.frameworkB\x0bGraphProtosP\x01ZLgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/graph_go_proto\xf8\x01\x01\x62\x06proto3')



_GRAPHDEF = DESCRIPTOR.message_types_by_name['GraphDef']
GraphDef = _reflection.GeneratedProtocolMessageType('GraphDef', (_message.Message,), {
  'DESCRIPTOR' : _GRAPHDEF,
  '__module__' : 'tensorboard.compat.proto.graph_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.GraphDef)
  })
_sym_db.RegisterMessage(GraphDef)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030org.tensorflow.frameworkB\013GraphProtosP\001ZLgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/graph_go_proto\370\001\001'
  _GRAPHDEF.fields_by_name['version']._options = None
  _GRAPHDEF.fields_by_name['version']._serialized_options = b'\030\001'
  _GRAPHDEF._serialized_start=177
  _GRAPHDEF._serialized_end=337
# @@protoc_insertion_point(module_scope)
